PolarExpress.Events (polar_express v0.1.5)

Copy Markdown View Source

Known PolarExpress webhook event type constants.

Summary

Functions

List of all known PolarExpress event types.

Check if a string is a known event type.

Functions

event_types()

@spec event_types() :: [String.t()]

List of all known PolarExpress event types.

valid_event_type?(type)

@spec valid_event_type?(String.t()) :: boolean()

Check if a string is a known event type.