PolarExpress.Events.BenefitGrantCycled (polar_express v0.1.5)

Copy Markdown View Source

Webhook event for benefit_grant.cycled.

Sent when a benefit grant is cycled, meaning the related subscription has been renewed for another period.

Discord & Slack support: Basic

The data field contains a PolarExpress.Schemas.BenefitGrantWebhook struct.

Summary

Functions

Returns the event type string.

Types

t()

@type t() :: %PolarExpress.Events.BenefitGrantCycled{
  data: PolarExpress.Schemas.BenefitGrantWebhook.t(),
  timestamp: String.t(),
  type: String.t()
}

Functions

event_type()

@spec event_type() :: String.t()

Returns the event type string.