PolarExpress.Events.CustomerSeatAssigned (polar_express v0.1.5)

Copy Markdown View Source

Webhook event for customer_seat.assigned.

Sent when a new customer seat is assigned.

This event is triggered when a seat is assigned to a customer by the organization. The customer will receive an invitation email to claim the seat.

The data field contains a PolarExpress.Schemas.CustomerSeat struct.

Summary

Functions

Returns the event type string.

Types

t()

@type t() :: %PolarExpress.Events.CustomerSeatAssigned{
  data: PolarExpress.Schemas.CustomerSeat.t(),
  timestamp: String.t(),
  type: String.t()
}

Functions

event_type()

@spec event_type() :: String.t()

Returns the event type string.