PolarExpress.Events.CustomerSeatRevoked (polar_express v0.1.5)

Copy Markdown View Source

Webhook event for customer_seat.revoked.

Sent when a customer seat is revoked.

This event is triggered when access to a seat is revoked, either manually by the organization or automatically when a subscription is canceled.

The data field contains a PolarExpress.Schemas.CustomerSeat struct.

Summary

Functions

Returns the event type string.

Types

t()

@type t() :: %PolarExpress.Events.CustomerSeatRevoked{
  data: PolarExpress.Schemas.CustomerSeat.t(),
  timestamp: String.t(),
  type: String.t()
}

Functions

event_type()

@spec event_type() :: String.t()

Returns the event type string.