PolarExpress.Events.MemberCreated (polar_express v0.1.5)

Copy Markdown View Source

Webhook event for member.created.

Sent when a new member is created.

A member represents an individual within a customer (team). This event is triggered when a member is added to a customer, either programmatically via the API or when an owner is automatically created for a new customer.

Discord & Slack support: Basic

The data field contains a PolarExpress.Schemas.Member struct.

Summary

Functions

Returns the event type string.

Types

t()

@type t() :: %PolarExpress.Events.MemberCreated{
  data: PolarExpress.Schemas.Member.t(),
  timestamp: String.t(),
  type: String.t()
}
  • type - Always "member.created".
  • data - The event payload. See PolarExpress.Schemas.Member.
  • timestamp - ISO 8601 timestamp of when the event occurred.

Functions

event_type()

@spec event_type() :: String.t()

Returns the event type string.