PolarExpress.Events.MemberDeleted (polar_express v0.1.5)

Copy Markdown View Source

Webhook event for member.deleted.

Sent when a member is deleted.

This event is triggered when a member is removed from a customer. Any active seats assigned to the member will be automatically revoked.

Discord & Slack support: Basic

The data field contains a PolarExpress.Schemas.Member struct.

Summary

Functions

Returns the event type string.

Types

t()

@type t() :: %PolarExpress.Events.MemberDeleted{
  data: PolarExpress.Schemas.Member.t(),
  timestamp: String.t(),
  type: String.t()
}
  • type - Always "member.deleted".
  • data - The event payload. See PolarExpress.Schemas.Member.
  • timestamp - ISO 8601 timestamp of when the event occurred.

Functions

event_type()

@spec event_type() :: String.t()

Returns the event type string.