PolarExpress.Events.SubscriptionActive (polar_express v0.1.5)

Copy Markdown View Source

Webhook event for subscription.active.

Sent when a subscription becomes active, whether because it's a new paid subscription or because payment was recovered.

Discord & Slack support: Full

The data field contains a PolarExpress.Schemas.Subscription struct.

Summary

Functions

Returns the event type string.

Types

t()

@type t() :: %PolarExpress.Events.SubscriptionActive{
  data: PolarExpress.Schemas.Subscription.t(),
  timestamp: String.t(),
  type: String.t()
}

Functions

event_type()

@spec event_type() :: String.t()

Returns the event type string.