PolarExpress.Events.SubscriptionCreated (polar_express v0.1.5)

Copy Markdown View Source

Webhook event for subscription.created.

Sent when a new subscription is created.

When this event occurs, the subscription status might not be active yet, as we can still have to wait for the first payment to be processed.

Discord & Slack support: Full

The data field contains a PolarExpress.Schemas.Subscription struct.

Summary

Functions

Returns the event type string.

Types

t()

@type t() :: %PolarExpress.Events.SubscriptionCreated{
  data: PolarExpress.Schemas.Subscription.t(),
  timestamp: String.t(),
  type: String.t()
}

Functions

event_type()

@spec event_type() :: String.t()

Returns the event type string.