PolarExpress.Events.SubscriptionUpdated (polar_express v0.1.5)

Copy Markdown View Source

Webhook event for subscription.updated.

Sent when a subscription is updated. This event fires for all changes to the subscription, including renewals.

If you want more specific events, you can listen to subscription.active, subscription.canceled, subscription.past_due, and subscription.revoked.

To listen specifically for renewals, you can listen to order.created events and check the billing_reason field.

Discord & Slack support: On cancellation, past due, and revocation. Renewals are skipped.

The data field contains a PolarExpress.Schemas.Subscription struct.

Summary

Functions

Returns the event type string.

Types

t()

@type t() :: %PolarExpress.Events.SubscriptionUpdated{
  data: PolarExpress.Schemas.Subscription.t(),
  timestamp: String.t(),
  type: String.t()
}

Functions

event_type()

@spec event_type() :: String.t()

Returns the event type string.