PolarExpress.Params.BenefitGrantsListBenefitGrantsParams
(polar_express v0.1.5)
Parameters for benefit grants list benefit grants.
Summary
Types
@type t() :: %PolarExpress.Params.BenefitGrantsListBenefitGrantsParams{ customer_id: map() | nil, external_customer_id: map() | nil, is_granted: boolean() | nil, limit: integer() | nil, organization_id: map() | nil, page: integer() | nil, sorting: [map()] | nil }
customer_id- Filter by customer ID.external_customer_id- Filter by customer external ID.is_granted- Filter by granted status. Iftrue, only granted benefits will be returned. Iffalse, only revoked benefits will be returned.limit- Size of a page, defaults to 10. Maximum is 100.organization_id- Filter by organization ID.page- Page number, defaults to 1.sorting- Sorting criterion. Several criteria can be used simultaneously and will be applied in order. Add a minus sign-before the criteria name to sort by descending order.