PolarExpress.Params.CheckoutLinksListCheckoutLinksParams
(polar_express v0.1.5)
Parameters for checkout links list checkout links.
Summary
Types
@type t() :: %PolarExpress.Params.CheckoutLinksListCheckoutLinksParams{ limit: integer() | nil, organization_id: map() | nil, page: integer() | nil, product_id: map() | nil, sorting: [map()] | nil }
limit- Size of a page, defaults to 10. Maximum is 100.organization_id- Filter by organization ID.page- Page number, defaults to 1.product_id- Filter by product ID.sorting- Sorting criterion. Several criteria can be used simultaneously and will be applied in order. Add a minus sign-before the criteria name to sort by descending order.