Parameters for discounts list discounts.
Summary
Types
@type t() :: %PolarExpress.Params.DiscountsListDiscountsParams{ limit: integer() | nil, organization_id: map() | nil, page: integer() | nil, query: String.t() | nil, sorting: [map()] | nil }
limit- Size of a page, defaults to 10. Maximum is 100.organization_id- Filter by organization ID.page- Page number, defaults to 1.query- Filter by name.sorting- Sorting criterion. Several criteria can be used simultaneously and will be applied in order. Add a minus sign-before the criteria name to sort by descending order.