PolarExpress.Params.OrganizationsListOrganizationsParams (polar_express v0.1.5)

Copy Markdown View Source

Parameters for organizations list organizations.

Summary

Types

t()

@type t() :: %PolarExpress.Params.OrganizationsListOrganizationsParams{
  limit: integer() | nil,
  page: integer() | nil,
  slug: String.t() | nil,
  sorting: [map()] | nil
}
  • limit - Size of a page, defaults to 10. Maximum is 100.
  • page - Page number, defaults to 1.
  • slug - Filter by slug.
  • sorting - Sorting criterion. Several criteria can be used simultaneously and will be applied in order. Add a minus sign - before the criteria name to sort by descending order.