PolarExpress.Resources.Payments (polar_express v0.1.5)

Copy Markdown View Source

Payments

Payments API operations.

Summary

Types

t()

@type t() :: %PolarExpress.Resources.Payments{
  amount: integer() | nil,
  checkout_id: term() | nil,
  created_at: String.t() | nil,
  currency: String.t() | nil,
  decline_message: term() | nil,
  decline_reason: term() | nil,
  id: String.t() | nil,
  method: String.t() | nil,
  method_metadata: map() | nil,
  modified_at: term() | nil,
  order_id: term() | nil,
  organization_id: String.t() | nil,
  processor: map() | nil,
  processor_metadata: map() | nil,
  status: map() | nil
}
  • amount - The payment amount in cents.
  • checkout_id - The ID of the checkout session associated with this payment.
  • created_at - Creation timestamp of the object. Format: date-time.
  • currency - The payment currency. Currently, only usd is supported.
  • decline_message - Human-reasable error message, if the payment was declined.
  • decline_reason - Error code, if the payment was declined.
  • id - The ID of the object. Format: uuid4.
  • method - The payment method used.
  • method_metadata - Additional metadata for the card payment method.
  • modified_at - Last modification timestamp of the object.
  • order_id - The ID of the order associated with this payment.
  • organization_id - The ID of the organization that owns the payment. Format: uuid4.
  • processor - The payment processor.
  • processor_metadata - Additional metadata from the payment processor for internal use.
  • status - The payment status.

Functions

object_name()