Subscriptions
Subscriptions API operations.
Summary
Types
@type t() :: %PolarExpress.Resources.Subscriptions{ amount: integer() | nil, cancel_at_period_end: boolean() | nil, canceled_at: term() | nil, checkout_id: term() | nil, created_at: String.t() | nil, currency: String.t() | nil, current_period_end: term() | nil, current_period_start: String.t() | nil, custom_field_data: term() | nil, customer: map() | nil, customer_cancellation_comment: term() | nil, customer_cancellation_reason: term() | nil, customer_id: String.t() | nil, discount: term() | nil, discount_id: term() | nil, ended_at: term() | nil, ends_at: term() | nil, id: String.t() | nil, metadata: map() | nil, meters: [map()] | nil, modified_at: term() | nil, prices: [term()] | nil, product: map() | nil, product_id: String.t() | nil, recurring_interval: map() | nil, recurring_interval_count: integer() | nil, seats: term() | nil, started_at: term() | nil, status: map() | nil, trial_end: term() | nil, trial_start: term() | nil }
amount- The amount of the subscription.cancel_at_period_end- Whether the subscription will be canceled at the end of the current period.canceled_at- The timestamp when the subscription was canceled. The subscription might still be active ifcancel_at_period_endistrue.checkout_idcreated_at- Creation timestamp of the object. Format: date-time.currency- The currency of the subscription.current_period_end- The end timestamp of the current billing period.current_period_start- The start timestamp of the current billing period. Format: date-time.custom_field_data- Key-value object storing custom field values.customercustomer_cancellation_commentcustomer_cancellation_reasoncustomer_id- The ID of the subscribed customer. Format: uuid4.discountdiscount_id- The ID of the applied discount, if any.ended_at- The timestamp when the subscription ended.ends_at- The timestamp when the subscription will end.id- The ID of the object. Format: uuid4.metadatameters- List of meters associated with the subscription.modified_at- Last modification timestamp of the object.prices- List of enabled prices for the subscription.productproduct_id- The ID of the subscribed product. Format: uuid4.recurring_interval- The interval at which the subscription recurs.recurring_interval_count- Number of interval units of the subscription. If this is set to 1 the charge will happen every interval (e.g. every month), if set to 2 it will be every other month, and so on.seats- The number of seats for seat-based subscriptions. None for non-seat subscriptions.started_at- The timestamp when the subscription started.status- The status of the subscription.trial_end- The end timestamp of the trial period, if any.trial_start- The start timestamp of the trial period, if any.