PolarExpress.Schemas.AttachedCustomField (polar_express v0.1.5)

Copy Markdown View Source

AttachedCustomField

Schema of a custom field attached to a resource.

Summary

Types

t()

@type t() :: %PolarExpress.Schemas.AttachedCustomField{
  custom_field: PolarExpress.Schemas.CustomField.t() | nil,
  custom_field_id: String.t() | nil,
  order: integer() | nil,
  required: boolean() | nil
}
  • custom_field
  • custom_field_id - ID of the custom field. Format: uuid4.
  • order - Order of the custom field in the resource.
  • required - Whether the value is required for this custom field.

Functions

schema_name()