PolarExpress.Schemas.AttachedCustomFieldCreate (polar_express v0.1.5)

Copy Markdown View Source

AttachedCustomFieldCreate

Schema to attach a custom field to a resource.

Summary

Types

t()

@type t() :: %PolarExpress.Schemas.AttachedCustomFieldCreate{
  custom_field_id: String.t() | nil,
  required: boolean() | nil
}
  • custom_field_id - ID of the custom field to attach. Format: uuid4.
  • required - Whether the value is required for this custom field.

Functions

schema_name()