BenefitCustom
A benefit of type custom.
Use it to grant any kind of benefit that doesn't fit in the other types.
Summary
Types
@type t() :: %PolarExpress.Schemas.BenefitCustom{ created_at: DateTime.t() | nil, deletable: boolean() | nil, description: String.t() | nil, id: String.t() | nil, metadata: PolarExpress.Schemas.MetadataOutputType.t() | nil, modified_at: DateTime.t() | nil, organization_id: String.t() | nil, properties: PolarExpress.Schemas.BenefitCustomProperties.t() | nil, selectable: boolean() | nil, type: String.t() | nil }
created_at- Creation timestamp of the object. Format: date-time.deletable- Whether the benefit is deletable.description- The description of the benefit.id- The ID of the benefit. Format: uuid4.metadatamodified_at- Last modification timestamp of the object. Nullable.organization_id- The ID of the organization owning the benefit. Format: uuid4.propertiesselectable- Whether the benefit is selectable when creating a product.type