PolarExpress.Schemas.BenefitDiscord (polar_express v0.1.5)

Copy Markdown View Source

BenefitDiscord

A benefit of type discord.

Use it to automatically invite your backers to a Discord server.

Summary

Types

t()

@type t() :: %PolarExpress.Schemas.BenefitDiscord{
  created_at: DateTime.t() | nil,
  deletable: boolean() | nil,
  description: String.t() | nil,
  id: String.t() | nil,
  metadata: PolarExpress.Schemas.MetadataOutputType.t() | nil,
  modified_at: DateTime.t() | nil,
  organization_id: String.t() | nil,
  properties: PolarExpress.Schemas.BenefitDiscordProperties.t() | nil,
  selectable: boolean() | nil,
  type: String.t() | nil
}
  • created_at - Creation timestamp of the object. Format: date-time.
  • deletable - Whether the benefit is deletable.
  • description - The description of the benefit.
  • id - The ID of the benefit. Format: uuid4.
  • metadata
  • modified_at - Last modification timestamp of the object. Nullable.
  • organization_id - The ID of the organization owning the benefit. Format: uuid4.
  • properties
  • selectable - Whether the benefit is selectable when creating a product.
  • type

Functions

schema_name()