PolarExpress.Schemas.CheckoutDiscountFixedRepeatDuration (polar_express v0.1.5)

Copy Markdown View Source

CheckoutDiscountFixedRepeatDuration

Schema for a fixed amount discount that is applied on every invoice for a certain number of months.

Summary

Types

t()

@type t() :: %PolarExpress.Schemas.CheckoutDiscountFixedRepeatDuration{
  amount: integer() | nil,
  code: String.t() | nil,
  currency: String.t() | nil,
  duration: PolarExpress.Schemas.DiscountDuration.t() | nil,
  duration_in_months: integer() | nil,
  id: String.t() | nil,
  name: String.t() | nil,
  type: PolarExpress.Schemas.DiscountType.t() | nil
}
  • amount
  • code - Nullable.
  • currency
  • duration
  • duration_in_months
  • id - The ID of the object. Format: uuid4.
  • name
  • type

Functions

schema_name()