PolarExpress.Schemas.CheckoutLinkCreateProducts (polar_express v0.1.5)

Copy Markdown View Source

CheckoutLinkCreateProducts

Schema to create a new checkout link.

Summary

Types

t()

@type t() :: %PolarExpress.Schemas.CheckoutLinkCreateProducts{
  allow_discount_codes: boolean() | nil,
  discount_id: String.t() | nil,
  label: String.t() | nil,
  metadata:
    %{
      required(String.t()) => String.t() | integer() | float() | boolean() | nil
    }
    | nil,
  payment_processor: String.t() | nil,
  products: [String.t()] | nil,
  require_billing_address: boolean() | nil,
  return_url: String.t() | nil,
  success_url: String.t() | nil,
  trial_interval: PolarExpress.Schemas.TrialInterval.t() | nil,
  trial_interval_count: integer() | nil
}
  • allow_discount_codes - Whether to allow the customer to apply discount codes. If you apply a discount through discount_id, it'll still be applied, but the customer won't be able to change it.
  • discount_id - ID of the discount to apply to the checkout. If the discount is not applicable anymore when opening the checkout link, it'll be ignored. Nullable.
  • label - Optional label to distinguish links internally Nullable.
  • metadata - Key-value object allowing you to store additional information.

The key must be a string with a maximum length of 40 characters. The value must be either:

  • A string with a maximum length of 500 characters
  • An integer
  • A floating-point number
  • A boolean

You can store up to 50 key-value pairs.

  • payment_processor - Payment processor to use. Currently only Stripe is supported.
  • products - List of products that will be available to select at checkout.
  • require_billing_address - Whether to require the customer to fill their full billing address, instead of just the country. Customers in the US will always be required to fill their full address, regardless of this setting.
  • return_url - When set, a back button will be shown in the checkout to return to this URL. Nullable.
  • success_url - URL where the customer will be redirected after a successful payment.You can add the checkout_id={CHECKOUT_ID} query parameter to retrieve the checkout session id. Nullable.
  • trial_interval - The interval unit for the trial period. Nullable.
  • trial_interval_count - The number of interval units for the trial period. Nullable.

Functions

schema_name()