PolarExpress.Schemas.CustomFieldUpdateDate (polar_express v0.1.5)

Copy Markdown View Source

CustomFieldUpdateDate

Schema to update a custom field of type date.

Summary

Types

t()

@type t() :: %PolarExpress.Schemas.CustomFieldUpdateDate{
  metadata:
    %{
      required(String.t()) => String.t() | integer() | float() | boolean() | nil
    }
    | nil,
  name: String.t() | nil,
  properties: PolarExpress.Schemas.CustomFieldDateProperties.t() | nil,
  slug: String.t() | nil,
  type: String.t() | nil
}
  • metadata - Key-value object allowing you to store additional information.

The key must be a string with a maximum length of 40 characters. The value must be either:

  • A string with a maximum length of 500 characters
  • An integer
  • A floating-point number
  • A boolean

You can store up to 50 key-value pairs.

  • name - Nullable.
  • properties - Nullable.
  • slug - Nullable.
  • type

Functions

schema_name()