PolarExpress.Schemas.CustomerSessionCustomerExternalIDCreate (polar_express v0.1.6)

Copy Markdown View Source

CustomerSessionCustomerExternalIDCreate

Schema for creating a customer session using an external customer ID.

Summary

Types

t()

@type t() :: %PolarExpress.Schemas.CustomerSessionCustomerExternalIDCreate{
  external_customer_id: String.t() | nil,
  external_member_id: String.t() | nil,
  member_id: String.t() | nil,
  return_url: String.t() | nil
}
  • external_customer_id - External ID of the customer to create a session for.
  • external_member_id - External ID of the member to create a session for. Alternative to member_id. Nullable.
  • member_id - ID of the member to create a session for. When not provided and the organization has member_model_enabled, the owner member of the customer will be used for individual customers. Nullable.
  • return_url - When set, a back button will be shown in the customer portal to return to this URL. Nullable.

Functions

schema_name()