PolarExpress.Schemas.CustomerStateBenefitGrant (polar_express v0.1.5)

Copy Markdown View Source

CustomerStateBenefitGrant

An active benefit grant for a customer.

Summary

Types

t()

  • benefit_id - The ID of the benefit concerned by this grant. Format: uuid4.
  • benefit_metadata - The metadata of the benefit concerned by this grant.
  • benefit_type - The type of the benefit concerned by this grant.
  • created_at - Creation timestamp of the object. Format: date-time.
  • granted_at - The timestamp when the benefit was granted. Format: date-time.
  • id - The ID of the grant. Format: uuid4.
  • modified_at - Last modification timestamp of the object. Nullable.
  • properties

Functions

schema_name()