DiscountUpdate
Schema to update a discount.
Summary
Types
@type t() :: %PolarExpress.Schemas.DiscountUpdate{ amount: integer() | nil, basis_points: integer() | nil, code: String.t() | nil, currency: PolarExpress.Schemas.PresentmentCurrency.t() | nil, duration: PolarExpress.Schemas.DiscountDuration.t() | nil, duration_in_months: integer() | nil, ends_at: DateTime.t() | nil, max_redemptions: integer() | nil, metadata: %{ required(String.t()) => String.t() | integer() | float() | boolean() | nil } | nil, name: String.t() | nil, products: [String.t()] | nil, starts_at: DateTime.t() | nil, type: PolarExpress.Schemas.DiscountType.t() | nil }
amount- Nullable.basis_points- Nullable.code- Code customers can use to apply the discount during checkout. Must be between 3 and 256 characters long and contain only alphanumeric characters.If not provided, the discount can only be applied via the API. Nullable.currency- Nullable.duration- Nullable.duration_in_months- Nullable.ends_at- Optional timestamp after which the discount is no longer redeemable. Nullable.max_redemptions- Optional maximum number of times the discount can be redeemed. Nullable.metadata- Key-value object allowing you to store additional information.
The key must be a string with a maximum length of 40 characters. The value must be either:
- A string with a maximum length of 500 characters
- An integer
- A floating-point number
- A boolean
You can store up to 50 key-value pairs.
name- Nullable.products- Nullable.starts_at- Optional timestamp after which the discount is redeemable. Nullable.type- Nullable.