ExistingProductPrice
A price that already exists for this product.
Useful when updating a product if you want to keep an existing price.
Summary
Types
@type t() :: %PolarExpress.Schemas.ExistingProductPrice{id: String.t() | nil}
id- Format: uuid4.
ExistingProductPrice
A price that already exists for this product.
Useful when updating a product if you want to keep an existing price.
@type t() :: %PolarExpress.Schemas.ExistingProductPrice{id: String.t() | nil}
id - Format: uuid4.