LicenseKeyActivate
Summary
Types
@type t() :: %PolarExpress.Schemas.LicenseKeyActivate{ conditions: %{ required(String.t()) => String.t() | integer() | float() | boolean() | nil } | nil, key: String.t() | nil, label: String.t() | nil, meta: %{ required(String.t()) => String.t() | integer() | float() | boolean() | nil } | nil, organization_id: String.t() | nil }
conditions- Key-value object allowing you to set conditions that must match when validating the license key.
The key must be a string with a maximum length of 40 characters. The value must be either:
- A string with a maximum length of 500 characters
- An integer
- A floating-point number
- A boolean
You can store up to 50 key-value pairs.
keylabelmeta- Key-value object allowing you to store additional information about the activation
The key must be a string with a maximum length of 40 characters. The value must be either:
- A string with a maximum length of 500 characters
- An integer
- A floating-point number
- A boolean
You can store up to 50 key-value pairs.
organization_id- Format: uuid4.