PolarExpress.Schemas.LicenseKeyValidate (polar_express v0.1.5)

Copy Markdown View Source

LicenseKeyValidate

Summary

Types

t()

@type t() :: %PolarExpress.Schemas.LicenseKeyValidate{
  activation_id: String.t() | nil,
  benefit_id: String.t() | nil,
  conditions:
    %{
      required(String.t()) => String.t() | integer() | float() | boolean() | nil
    }
    | nil,
  customer_id: String.t() | nil,
  increment_usage: integer() | nil,
  key: String.t() | nil,
  organization_id: String.t() | nil
}
  • activation_id - Nullable.
  • benefit_id - Nullable.
  • conditions - Key-value object allowing you to set conditions that must match when validating the license key.

The key must be a string with a maximum length of 40 characters. The value must be either:

  • A string with a maximum length of 500 characters
  • An integer
  • A floating-point number
  • A boolean

You can store up to 50 key-value pairs.

  • customer_id - Nullable.
  • increment_usage - Nullable.
  • key
  • organization_id - Format: uuid4.

Functions

schema_name()