PolarExpress.Schemas.MemberSessionCreate (polar_express v0.1.5)

Copy Markdown View Source

MemberSessionCreate

Schema for creating a member session using a member ID.

Summary

Types

t()

@type t() :: %PolarExpress.Schemas.MemberSessionCreate{
  member_id: String.t() | nil,
  return_url: String.t() | nil
}
  • member_id - ID of the member to create a session for. Format: uuid4.
  • return_url - When set, a back button will be shown in the customer portal to return to this URL. Nullable.

Functions

schema_name()