PolarExpress.Schemas.ProductBenefitsUpdate (polar_express v0.1.5)

Copy Markdown View Source

ProductBenefitsUpdate

Schema to update the benefits granted by a product.

Summary

Types

t()

@type t() :: %PolarExpress.Schemas.ProductBenefitsUpdate{benefits: [String.t()] | nil}
  • benefits - List of benefit IDs. Each one must be on the same organization as the product.

Functions

schema_name()