PolarExpress.Schemas.ProductPriceCustom (polar_express v0.1.5)

Copy Markdown View Source

ProductPriceCustom

A pay-what-you-want price for a product.

Summary

Types

t()

@type t() :: %PolarExpress.Schemas.ProductPriceCustom{
  amount_type: String.t() | nil,
  created_at: DateTime.t() | nil,
  id: String.t() | nil,
  is_archived: boolean() | nil,
  maximum_amount: integer() | nil,
  minimum_amount: integer() | nil,
  modified_at: DateTime.t() | nil,
  preset_amount: integer() | nil,
  price_currency: String.t() | nil,
  product_id: String.t() | nil,
  recurring_interval:
    PolarExpress.Schemas.SubscriptionRecurringInterval.t() | nil,
  source: PolarExpress.Schemas.ProductPriceSource.t() | nil,
  type: PolarExpress.Schemas.ProductPriceType.t() | nil
}
  • amount_type
  • created_at - Creation timestamp of the object. Format: date-time.
  • id - The ID of the price. Format: uuid4.
  • is_archived - Whether the price is archived and no longer available.
  • maximum_amount - The maximum amount the customer can pay. Nullable.
  • minimum_amount - The minimum amount the customer can pay. If 0, the price is 'free or pay what you want'. Defaults to 50 cents.
  • modified_at - Last modification timestamp of the object. Nullable.
  • preset_amount - The initial amount shown to the customer. Nullable.
  • price_currency - The currency in which the customer will be charged.
  • product_id - The ID of the product owning the price. Format: uuid4.
  • recurring_interval - Nullable. Deprecated.
  • source - The source of the price . catalog is a predefined price, while ad_hoc is a price created dynamically on a Checkout session.
  • type - Deprecated.

Functions

schema_name()