ProductPriceFixed
A fixed price for a product.
Summary
Types
@type t() :: %PolarExpress.Schemas.ProductPriceFixed{ amount_type: String.t() | nil, created_at: DateTime.t() | nil, id: String.t() | nil, is_archived: boolean() | nil, modified_at: DateTime.t() | nil, price_amount: integer() | nil, price_currency: String.t() | nil, product_id: String.t() | nil, recurring_interval: PolarExpress.Schemas.SubscriptionRecurringInterval.t() | nil, source: PolarExpress.Schemas.ProductPriceSource.t() | nil, type: PolarExpress.Schemas.ProductPriceType.t() | nil }
amount_typecreated_at- Creation timestamp of the object. Format: date-time.id- The ID of the price. Format: uuid4.is_archived- Whether the price is archived and no longer available.modified_at- Last modification timestamp of the object. Nullable.price_amount- The price in cents.price_currency- The currency in which the customer will be charged.product_id- The ID of the product owning the price. Format: uuid4.recurring_interval- Nullable. Deprecated.source- The source of the price .catalogis a predefined price, whilead_hocis a price created dynamically on a Checkout session.type- Deprecated.