PolarExpress.Schemas.SubscriptionBillingPeriodUpdatedEvent (polar_express v0.1.5)

Copy Markdown View Source

SubscriptionBillingPeriodUpdatedEvent

An event created by Polar when a subscription billing period is updated.

Summary

Types

t()

@type t() :: %PolarExpress.Schemas.SubscriptionBillingPeriodUpdatedEvent{
  child_count: integer() | nil,
  customer: PolarExpress.Schemas.Customer.t() | nil,
  customer_id: String.t() | nil,
  external_customer_id: String.t() | nil,
  external_member_id: String.t() | nil,
  id: String.t() | nil,
  label: String.t() | nil,
  member_id: String.t() | nil,
  metadata:
    PolarExpress.Schemas.SubscriptionBillingPeriodUpdatedMetadata.t() | nil,
  name: String.t() | nil,
  organization_id: String.t() | nil,
  parent_id: String.t() | nil,
  source: String.t() | nil,
  timestamp: DateTime.t() | nil
}
  • child_count - Number of direct child events linked to this event.
  • customer - The customer associated with the event. Nullable.
  • customer_id - ID of the customer in your Polar organization associated with the event. Nullable.
  • external_customer_id - ID of the customer in your system associated with the event. Nullable.
  • external_member_id - ID of the member in your system within the customer's organization who performed the action inside B2B. Nullable.
  • id - The ID of the object. Format: uuid4.
  • label - Human readable label of the event type.
  • member_id - ID of the member within the customer's organization who performed the action inside B2B. Nullable.
  • metadata
  • name - The name of the event.
  • organization_id - The ID of the organization owning the event. Format: uuid4.
  • parent_id - The ID of the parent event. Nullable.
  • source - The source of the event. system events are created by Polar. user events are the one you create through our ingestion API.
  • timestamp - The timestamp of the event. Format: date-time.

Functions

schema_name()