PolarExpress.Schemas.SubscriptionCreateCustomer (polar_express v0.1.5)

Copy Markdown View Source

SubscriptionCreateCustomer

Create a subscription for an existing customer.

Summary

Types

t()

@type t() :: %PolarExpress.Schemas.SubscriptionCreateCustomer{
  customer_id: String.t() | nil,
  metadata:
    %{
      required(String.t()) => String.t() | integer() | float() | boolean() | nil
    }
    | nil,
  product_id: String.t() | nil
}
  • customer_id - The ID of the customer to create the subscription for. Format: uuid4.
  • metadata - Key-value object allowing you to store additional information.

The key must be a string with a maximum length of 40 characters. The value must be either:

  • A string with a maximum length of 500 characters
  • An integer
  • A floating-point number
  • A boolean

You can store up to 50 key-value pairs.

  • product_id - The ID of the recurring product to subscribe to. Must be a free product, otherwise the customer should go through a checkout flow. Format: uuid4.

Functions

schema_name()