PolarExpress.Schemas.SubscriptionUpdateBillingPeriod (polar_express v0.1.5)

Copy Markdown View Source

SubscriptionUpdateBillingPeriod

Summary

Types

t()

@type t() :: %PolarExpress.Schemas.SubscriptionUpdateBillingPeriod{
  current_billing_period_end: DateTime.t() | nil
}
  • current_billing_period_end - Set a new date for the end of the current billing period. The subscription will renew on this date. Needs to be later than the current value.

It is not possible to update the current billing period on a canceled subscription. Format: date-time.

Functions

schema_name()