PolarExpress.Schemas.SubscriptionUpdateDiscount (polar_express v0.1.5)

Copy Markdown View Source

SubscriptionUpdateDiscount

Summary

Types

t()

@type t() :: %PolarExpress.Schemas.SubscriptionUpdateDiscount{
  discount_id: String.t() | nil
}
  • discount_id - Update the subscription to apply a new discount. If set to null, the discount will be removed. The change will be applied on the next billing cycle. Nullable.

Functions

schema_name()