PolarExpress.Schemas.SubscriptionUpdateTrial (polar_express v0.1.5)

Copy Markdown View Source

SubscriptionUpdateTrial

Summary

Types

t()

@type t() :: %PolarExpress.Schemas.SubscriptionUpdateTrial{
  trial_end: DateTime.t() | String.t() | nil
}
  • trial_end - Set or extend the trial period of the subscription. If set to now, the trial will end immediately.

Functions

schema_name()