PolarExpress.Schemas.WebhookBenefitGrantCycledPayload (polar_express v0.1.5)

Copy Markdown View Source

WebhookBenefitGrantCycledPayload

Sent when a benefit grant is cycled, meaning the related subscription has been renewed for another period.

Discord & Slack support: Basic

Summary

Types

t()

@type t() :: %PolarExpress.Schemas.WebhookBenefitGrantCycledPayload{
  data: PolarExpress.Schemas.BenefitGrantWebhook.t() | nil,
  timestamp: DateTime.t() | nil,
  type: String.t() | nil
}
  • data
  • timestamp - Format: date-time.
  • type

Functions

schema_name()