WebhookCheckoutExpiredPayload
Sent when a checkout expires.
This event fires when a checkout reaches its expiration time without being completed. Developers can use this to send reminder emails or track checkout abandonment.
Discord & Slack support: Basic
Summary
Types
@type t() :: %PolarExpress.Schemas.WebhookCheckoutExpiredPayload{ data: PolarExpress.Schemas.Checkout.t() | nil, timestamp: DateTime.t() | nil, type: String.t() | nil }
datatimestamp- Format: date-time.type