PolarExpress.Schemas.WebhookCustomerSeatAssignedPayload (polar_express v0.1.5)

Copy Markdown View Source

WebhookCustomerSeatAssignedPayload

Sent when a new customer seat is assigned.

This event is triggered when a seat is assigned to a customer by the organization. The customer will receive an invitation email to claim the seat.

Summary

Types

t()

@type t() :: %PolarExpress.Schemas.WebhookCustomerSeatAssignedPayload{
  data: PolarExpress.Schemas.CustomerSeat.t() | nil,
  timestamp: DateTime.t() | nil,
  type: String.t() | nil
}
  • data
  • timestamp - Format: date-time.
  • type

Functions

schema_name()