PolarExpress.Schemas.WebhookMemberUpdatedPayload (polar_express v0.1.5)

Copy Markdown View Source

WebhookMemberUpdatedPayload

Sent when a member is updated.

This event is triggered when member details are updated, such as their name or role within the customer.

Discord & Slack support: Basic

Summary

Types

t()

@type t() :: %PolarExpress.Schemas.WebhookMemberUpdatedPayload{
  data: PolarExpress.Schemas.Member.t() | nil,
  timestamp: DateTime.t() | nil,
  type: String.t() | nil
}
  • data
  • timestamp - Format: date-time.
  • type

Functions

schema_name()