PolarExpress.Schemas.WebhookOrderCreatedPayload (polar_express v0.1.5)

Copy Markdown View Source

WebhookOrderCreatedPayload

Sent when a new order is created.

A new order is created when:

  • A customer purchases a one-time product. In this case, billing_reason is set to purchase.
  • A customer starts a subscription. In this case, billing_reason is set to subscription_create.
  • A subscription is renewed. In this case, billing_reason is set to subscription_cycle.
  • A subscription is upgraded or downgraded with an immediate proration invoice. In this case, billing_reason is set to subscription_update.

[!WARNING] The order might not be paid yet, so the status field might be pending.

Discord & Slack support: Full

Summary

Types

t()

@type t() :: %PolarExpress.Schemas.WebhookOrderCreatedPayload{
  data: PolarExpress.Schemas.Order.t() | nil,
  timestamp: DateTime.t() | nil,
  type: String.t() | nil
}
  • data
  • timestamp - Format: date-time.
  • type

Functions

schema_name()