PolarExpress.Schemas.WebhookSubscriptionUpdatedPayload (polar_express v0.1.5)

Copy Markdown View Source

WebhookSubscriptionUpdatedPayload

Sent when a subscription is updated. This event fires for all changes to the subscription, including renewals.

If you want more specific events, you can listen to subscription.active, subscription.canceled, subscription.past_due, and subscription.revoked.

To listen specifically for renewals, you can listen to order.created events and check the billing_reason field.

Discord & Slack support: On cancellation, past due, and revocation. Renewals are skipped.

Summary

Types

t()

@type t() :: %PolarExpress.Schemas.WebhookSubscriptionUpdatedPayload{
  data: PolarExpress.Schemas.Subscription.t() | nil,
  timestamp: DateTime.t() | nil,
  type: String.t() | nil
}
  • data
  • timestamp - Format: date-time.
  • type

Functions

schema_name()