StripeElixir.Events (stripe_elixir v0.1.0)

Copy Markdown View Source

Known Stripe event type constants.

Summary

Functions

List of all known Stripe event types.

Check if a string is a known event type.

Functions

event_types()

List of all known Stripe event types.

valid_event_type?(type)

Check if a string is a known event type.