Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.AccountCreateParams.Controller{ fees: map() | nil, losses: map() | nil, requirement_collection: String.t() | nil, stripe_dashboard: map() | nil }
fees- A hash of configuration for who pays Stripe fees for product usage on this account.losses- A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.requirement_collection- A value indicating responsibility for collecting updated information when requirements on the account are due or change. Defaults tostripe. Possible values:application,stripe.stripe_dashboard- A hash of configuration for Stripe-hosted dashboards.