StripeElixir.Params.AccountExternalAccountUpdateParams.Documents (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.AccountExternalAccountUpdateParams.Documents{
  bank_account_ownership_verification: map() | nil
}
  • bank_account_ownership_verification - One or more documents that support the Bank account ownership verification requirement. Must be a document associated with the bank account that displays the last 4 digits of the account number, either a statement or a check.