Parameters for account login link create.
Summary
Types
@type t() :: %StripeElixir.Params.AccountLoginLinkCreateParams{ expand: [String.t()] | nil }
expand- Specifies which fields in the response should be expanded.
Parameters for account login link create.
@type t() :: %StripeElixir.Params.AccountLoginLinkCreateParams{ expand: [String.t()] | nil }
expand - Specifies which fields in the response should be expanded.