StripeElixir.Params.AccountUpdateParams.BusinessProfile
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.AccountUpdateParams.BusinessProfile{ annual_revenue: map() | nil, estimated_worker_count: integer() | nil, mcc: String.t() | nil, minority_owned_business_designation: [String.t()] | nil, monthly_estimated_revenue: map() | nil, name: String.t() | nil, product_description: String.t() | nil, support_address: map() | nil, support_email: String.t() | nil, support_phone: String.t() | nil, support_url: map() | nil, url: String.t() | nil }
annual_revenue- The applicant's gross annual revenue for its preceding fiscal year.estimated_worker_count- An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.mcc- The merchant category code for the account. MCCs are used to classify businesses based on the goods or services they provide. Max length: 4.minority_owned_business_designation- Whether the business is a minority-owned, women-owned, and/or LGBTQI+ -owned business.monthly_estimated_revenue- An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.name- The customer-facing business name. Max length: 5000.product_description- Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes. Max length: 40000.support_address- A publicly available mailing address for sending support issues to.support_email- A publicly available email address for sending support issues to.support_phone- A publicly available phone number to call with support issues. Max length: 5000.support_url- A publicly available website for handling support issues.url- The business's publicly available website.