StripeElixir.Params.Apps.SecretListParams.Scope (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Apps.SecretListParams.Scope{
  type: String.t() | nil,
  user: String.t() | nil
}
  • type - The secret scope type. Possible values: account, user.
  • user - The user ID. This field is required if type is set to user, and should not be provided if type is set to account. Max length: 5000.