StripeElixir.Params.Billing.CreditBalanceSummaryRetrieveParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for credit balance summary retrieve.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Billing.CreditBalanceSummaryRetrieveParams{
  customer: String.t() | nil,
  customer_account: String.t() | nil,
  expand: [String.t()] | nil,
  filter: map()
}
  • customer - The customer whose credit balance summary you're retrieving. Max length: 5000.
  • customer_account - The account representing the customer whose credit balance summary you're retrieving. Max length: 5000.
  • expand - Specifies which fields in the response should be expanded.
  • filter - The filter criteria for the credit balance summary.