StripeElixir.Params.ChargeCaptureParams.TransferData (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.ChargeCaptureParams.TransferData{
  amount: integer() | nil
}
  • amount - The amount transferred to the destination account, if specified. By default, the entire charge amount is transferred to the destination account.