StripeElixir.Params.ChargeCreateParams.TransferData (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.ChargeCreateParams.TransferData{
  amount: integer() | nil,
  destination: String.t() | nil
}
  • amount - The amount transferred to the destination account, if specified. By default, the entire charge amount is transferred to the destination account.
  • destination - ID of an existing, connected Stripe account. Max length: 5000.