StripeElixir.Params.Checkout.SessionCreateParams.AutomaticTax (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Checkout.SessionCreateParams.AutomaticTax{
  enabled: boolean() | nil,
  liability: map() | nil
}

Enabling this parameter causes Checkout to collect any billing address information necessary for tax calculation.

  • liability - The account that's liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.