StripeElixir.Params.Checkout.SessionCreateParams.BrandingSettings
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.Checkout.SessionCreateParams.BrandingSettings{ background_color: map() | nil, border_style: String.t() | nil, button_color: map() | nil, display_name: String.t() | nil, font_family: String.t() | nil, icon: map() | nil, logo: map() | nil }
background_color- A hex color value starting with#representing the background color for the Checkout Session.border_style- The border style for the Checkout Session. Possible values:pill,rectangular,rounded.button_color- A hex color value starting with#representing the button color for the Checkout Session.display_name- A string to override the business name shown on the Checkout Session. This only shows at the top of the Checkout page, and your business name still appears in terms, receipts, and other places. Max length: 5000.font_family- The font family for the Checkout Session corresponding to one of the supported font families. Possible values:be_vietnam_pro,bitter,chakra_petch,default,hahmlet,inconsolata,inter,lato,lora,m_plus_1_code,montserrat,noto_sans,noto_sans_jp,noto_serif,nunito,open_sans,pridi,pt_sans,pt_serif,raleway,roboto,roboto_slab,source_sans_pro,titillium_web,ubuntu_mono,zen_maru_gothic.icon- The icon for the Checkout Session. For best results, use a square image.logo- The logo for the Checkout Session.