StripeElixir.Params.Checkout.SessionCreateParams.ShippingOptions (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Checkout.SessionCreateParams.ShippingOptions{
  shipping_rate: String.t() | nil,
  shipping_rate_data: map() | nil
}
  • shipping_rate - The ID of the Shipping Rate to use for this shipping option. Max length: 5000.
  • shipping_rate_data - Parameters to be passed to Shipping Rate creation for this shipping option.