StripeElixir.Params.Checkout.SessionCreateParams.SubscriptionData
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.Checkout.SessionCreateParams.SubscriptionData{ application_fee_percent: float() | nil, billing_cycle_anchor: integer() | nil, billing_mode: map() | nil, default_tax_rates: [String.t()] | nil, description: String.t() | nil, invoice_settings: map() | nil, metadata: map() | nil, on_behalf_of: String.t() | nil, proration_behavior: String.t() | nil, transfer_data: map() | nil, trial_end: integer() | nil, trial_period_days: integer() | nil, trial_settings: map() | nil }
application_fee_percent- A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner's Stripe account. To use an application fee percent, the request must be made on behalf of another account, using theStripe-Accountheader or an OAuth key. For more information, see the application fees documentation.billing_cycle_anchor- A future timestamp to anchor the subscription's billing cycle for new subscriptions. You can't set this parameter ifui_modeiscustom. Format: Unix timestamp.billing_mode- Controls how prorations and invoices for subscriptions are calculated and orchestrated.default_tax_rates- The tax rates that will apply to any subscription item that does not havetax_ratesset. Invoices created will have theirdefault_tax_ratespopulated from the subscription.description- The subscription's description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in the customer portal. Max length: 500.invoice_settings- All invoices will be billed using the specified settings.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.on_behalf_of- The account on behalf of which to charge, for each of the subscription's invoices.proration_behavior- Determines how to handle prorations resulting from thebilling_cycle_anchor. If no value is passed, the default iscreate_prorations. Possible values:create_prorations,none.transfer_data- If specified, the funds from the subscription's invoices will be transferred to the destination and the ID of the resulting transfers will be found on the resulting charges.trial_end- Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. Has to be at least 48 hours in the future. Format: Unix timestamp.trial_period_days- Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.trial_settings- Settings related to subscription trials.