StripeElixir.Params.CreditNotePreviewLinesPreviewLinesParams.Lines
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.CreditNotePreviewLinesPreviewLinesParams.Lines{ amount: integer() | nil, description: String.t() | nil, invoice_line_item: String.t() | nil, quantity: integer() | nil, tax_amounts: map() | nil, tax_rates: map() | nil, type: String.t() | nil, unit_amount: integer() | nil, unit_amount_decimal: String.t() | nil }
amount- The line item amount to credit. Only valid whentypeisinvoice_line_item. If invoice is set up withautomatic_tax[enabled]=true, this amount is tax exclusivedescription- The description of the credit note line item. Only valid when thetypeiscustom_line_item. Max length: 5000.invoice_line_item- The invoice line item to credit. Only valid when thetypeisinvoice_line_item. Max length: 5000.quantity- The line item quantity to credit.tax_amounts- A list of up to 10 tax amounts for the credit note line item. Cannot be mixed withtax_rates.tax_rates- The tax rates which apply to the credit note line item. Only valid when thetypeiscustom_line_itemand cannot be mixed withtax_amounts.type- Type of the credit note line item, one ofinvoice_line_itemorcustom_line_itemPossible values:custom_line_item,invoice_line_item.unit_amount- The integer unit amount in cents (or local equivalent) of the credit note line item. Thisunit_amountwill be multiplied by the quantity to get the full amount to credit for this line item. Only valid whentypeiscustom_line_item.unit_amount_decimal- Same asunit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one ofunit_amountandunit_amount_decimalcan be set. Format: decimal string.