StripeElixir.Params.CustomerPaymentSourceCreateParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for customer payment source create.

Summary

Types

t()

@type t() :: %StripeElixir.Params.CustomerPaymentSourceCreateParams{
  expand: [String.t()] | nil,
  metadata: map() | nil,
  source: String.t(),
  validate: boolean() | nil
}
  • expand - Specifies which fields in the response should be expanded.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • source - Please refer to full documentation instead. Max length: 5000.
  • validate