StripeElixir.Params.CustomerPaymentSourceVerifyParams
(stripe_elixir v0.1.0)
Parameters for customer payment source verify.
Summary
Types
@type t() :: %StripeElixir.Params.CustomerPaymentSourceVerifyParams{ amounts: [integer()] | nil, expand: [String.t()] | nil }
amounts- Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.expand- Specifies which fields in the response should be expanded.