StripeElixir.Params.Entitlements.FeatureListParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for feature list.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Entitlements.FeatureListParams{
  archived: boolean() | nil,
  ending_before: String.t() | nil,
  expand: [String.t()] | nil,
  limit: integer() | nil,
  lookup_key: String.t() | nil,
  starting_after: String.t() | nil
}
  • archived - If set, filter results to only include features with the given archive status.
  • ending_before - A cursor for use in pagination. ending_before is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with obj_bar, your subsequent call can include ending_before=obj_bar in order to fetch the previous page of the list. Max length: 5000.
  • expand - Specifies which fields in the response should be expanded.
  • limit - A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
  • lookup_key - If set, filter results to only include features with the given lookup_key. Max length: 5000.
  • starting_after - A cursor for use in pagination. starting_after is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include starting_after=obj_foo in order to fetch the next page of the list. Max length: 5000.