StripeElixir.Params.FinancialConnections.AccountRefreshParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for account refresh.

Summary

Types

t()

@type t() :: %StripeElixir.Params.FinancialConnections.AccountRefreshParams{
  expand: [String.t()] | nil,
  features: [String.t()]
}
  • expand - Specifies which fields in the response should be expanded.
  • features - The list of account features that you would like to refresh.