StripeElixir.Params.FinancialConnections.SessionCreateParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for session create.

Summary

Types

t()

@type t() :: %StripeElixir.Params.FinancialConnections.SessionCreateParams{
  account_holder: map(),
  expand: [String.t()] | nil,
  filters: map() | nil,
  permissions: [String.t()],
  prefetch: [String.t()] | nil,
  return_url: String.t() | nil
}
  • account_holder - The account holder to link accounts for.
  • expand - Specifies which fields in the response should be expanded.
  • filters - Filters to restrict the kinds of accounts to collect.
  • permissions - List of data features that you would like to request access to.

Possible values are balances, transactions, ownership, and payment_method.

  • prefetch - List of data features that you would like to retrieve upon account creation.
  • return_url - For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app. Max length: 5000.