StripeElixir.Params.InvoiceRemoveLinesParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for invoice remove lines.

Summary

Types

t()

@type t() :: %StripeElixir.Params.InvoiceRemoveLinesParams{
  expand: [String.t()] | nil,
  invoice_metadata: map() | nil,
  lines: [map()]
}
  • expand - Specifies which fields in the response should be expanded.
  • invoice_metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • lines - The line items to remove.