Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.InvoiceRemoveLinesParams.Lines{ behavior: String.t() | nil, id: String.t() | nil }
behavior- Eitherdeleteorunassign. Deleted line items are permanently deleted. Unassigned line items can be reassigned to an invoice. Possible values:delete,unassign.id- ID of an existing line item to remove from this invoice. Max length: 5000.