Parameters for invoice send invoice.
Summary
Types
@type t() :: %StripeElixir.Params.InvoiceSendInvoiceParams{expand: [String.t()] | nil}
expand- Specifies which fields in the response should be expanded.
Parameters for invoice send invoice.
@type t() :: %StripeElixir.Params.InvoiceSendInvoiceParams{expand: [String.t()] | nil}
expand - Specifies which fields in the response should be expanded.