StripeElixir.Params.PaymentIntentApplyCustomerBalanceParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for payment intent apply customer balance.

Summary

Types

t()

@type t() :: %StripeElixir.Params.PaymentIntentApplyCustomerBalanceParams{
  amount: integer() | nil,
  currency: String.t() | nil,
  expand: [String.t()] | nil
}
  • amount - Amount that you intend to apply to this PaymentIntent from the customer’s cash balance. If the PaymentIntent was created by an Invoice, the full amount of the PaymentIntent is applied regardless of this parameter.

A positive integer representing how much to charge in the smallest currency unit (for example, 100 cents to charge 1 USD or 100 to charge 100 JPY, a zero-decimal currency). The maximum amount is the amount of the PaymentIntent.

When you omit the amount, it defaults to the remaining amount requested on the PaymentIntent.

  • currency - Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.
  • expand - Specifies which fields in the response should be expanded.