StripeElixir.Params.PaymentLinkCreateParams.CustomFields (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.PaymentLinkCreateParams.CustomFields{
  dropdown: map() | nil,
  key: String.t() | nil,
  label: map() | nil,
  numeric: map() | nil,
  optional: boolean() | nil,
  text: map() | nil,
  type: String.t() | nil
}
  • dropdown - Configuration for type=dropdown fields.
  • key - String of your choice that your integration can use to reconcile this field. Must be unique to this field, alphanumeric, and up to 200 characters. Max length: 200.
  • label - The label for the field, displayed to the customer.
  • numeric - Configuration for type=numeric fields.
  • optional - Whether the customer is required to complete the field before completing the Checkout Session. Defaults to false.
  • text - Configuration for type=text fields.
  • type - The type of the field. Possible values: dropdown, numeric, text.