StripeElixir.Params.PaymentLinkUpdateParams.PaymentIntentData
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.PaymentLinkUpdateParams.PaymentIntentData{ description: map() | nil, metadata: map() | nil, statement_descriptor: map() | nil, statement_descriptor_suffix: map() | nil, transfer_group: map() | nil }
description- An arbitrary string attached to the object. Often useful for displaying to users.metadata- Set of key-value pairs that will declaratively set metadata on Payment Intents generated from this payment link. Unlike object-level metadata, this field is declarative. Updates will clear prior values.statement_descriptor- Text that appears on the customer's statement as the statement descriptor for a non-card charge. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see the Statement Descriptor docs.
Setting this value for a card charge returns an error. For card charges, set the statement_descriptor_suffix instead.
statement_descriptor_suffix- Provides information about a card charge. Concatenated to the account's statement descriptor prefix to form the complete statement descriptor that appears on the customer's statement.transfer_group- A string that identifies the resulting payment as part of a group. See the PaymentIntents use case for connected accounts for details.