Parameters for payment method detach.
Summary
Types
@type t() :: %StripeElixir.Params.PaymentMethodDetachParams{ expand: [String.t()] | nil }
expand- Specifies which fields in the response should be expanded.
Parameters for payment method detach.
@type t() :: %StripeElixir.Params.PaymentMethodDetachParams{ expand: [String.t()] | nil }
expand - Specifies which fields in the response should be expanded.