StripeElixir.Params.PaymentMethodDomainCreateParams
(stripe_elixir v0.1.0)
Parameters for payment method domain create.
Summary
Types
@type t() :: %StripeElixir.Params.PaymentMethodDomainCreateParams{ domain_name: String.t(), enabled: boolean() | nil, expand: [String.t()] | nil }
domain_name- The domain name that this payment method domain object represents. Max length: 5000.enabled- Whether this payment method domain is enabled. If the domain is not enabled, payment methods that require a payment method domain will not appear in Elements or Embedded Checkout.expand- Specifies which fields in the response should be expanded.