Parameters for payment method domain list.
Summary
Types
@type t() :: %StripeElixir.Params.PaymentMethodDomainListParams{ domain_name: String.t() | nil, enabled: boolean() | nil, ending_before: String.t() | nil, expand: [String.t()] | nil, limit: integer() | nil, starting_after: String.t() | nil }
domain_name- The domain name that this payment method domain object represents. Max length: 5000.enabled- Whether this payment method domain is enabled. If the domain is not enabled, payment methods will not appear in Elements or Embedded Checkoutending_before- A cursor for use in pagination.ending_beforeis an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting withobj_bar, your subsequent call can includeending_before=obj_barin order to fetch the previous page of the list. Max length: 5000.expand- Specifies which fields in the response should be expanded.limit- A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.starting_after- A cursor for use in pagination.starting_afteris an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending withobj_foo, your subsequent call can includestarting_after=obj_fooin order to fetch the next page of the list. Max length: 5000.