StripeElixir.Params.PaymentRecordReportPaymentParams.PaymentMethodDetails (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %StripeElixir.Params.PaymentRecordReportPaymentParams.PaymentMethodDetails{
    billing_details: map() | nil,
    custom: map() | nil,
    payment_method: String.t() | nil,
    type: String.t() | nil
  }
  • billing_details - The billing details associated with the method of payment.
  • custom - Information about the custom (user-defined) payment method used to make this payment.
  • payment_method - ID of the Stripe Payment Method used to make this payment. Max length: 5000.
  • type - The type of the payment method details. An additional hash is included on the payment_method_details with a name matching this value. It contains additional information specific to the type. Possible values: custom.