StripeElixir.Params.PromotionCodeCreateParams.Restrictions
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.PromotionCodeCreateParams.Restrictions{ currency_options: map() | nil, first_time_transaction: boolean() | nil, minimum_amount: integer() | nil, minimum_amount_currency: String.t() | nil }
currency_options- Promotion codes defined in each available currency option. Each key must be a three-letter ISO currency code and a supported currency.first_time_transaction- A Boolean indicating if the Promotion Code should only be redeemed for Customers without any successful payments or invoicesminimum_amount- Minimum amount required to redeem this Promotion Code into a Coupon (e.g., a purchase must be $100 or more to work).minimum_amount_currency- Three-letter ISO code for minimum_amount Format: ISO 4217 currency code.