StripeElixir.Params.QuoteCreateParams.FromQuote (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.QuoteCreateParams.FromQuote{
  is_revision: boolean() | nil,
  quote: String.t() | nil
}
  • is_revision - Whether this quote is a revision of the previous quote.
  • quote - The id of the quote that will be cloned. Max length: 5000.