StripeElixir.Params.Radar.PaymentEvaluationCreateParams.ClientDeviceMetadataDetails
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.Radar.PaymentEvaluationCreateParams.ClientDeviceMetadataDetails{ radar_session: String.t() | nil }
radar_session- ID for the Radar Session to associate with the payment evaluation. A Radar Session is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments. Max length: 5000.