Parameters for value list retrieve.
Summary
Types
@type t() :: %StripeElixir.Params.Radar.ValueListRetrieveParams{ expand: [String.t()] | nil }
expand- Specifies which fields in the response should be expanded.
Parameters for value list retrieve.
@type t() :: %StripeElixir.Params.Radar.ValueListRetrieveParams{ expand: [String.t()] | nil }
expand - Specifies which fields in the response should be expanded.