StripeElixir.Params.Radar.ValueListUpdateParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for value list update.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Radar.ValueListUpdateParams{
  alias: String.t() | nil,
  expand: [String.t()] | nil,
  metadata: map() | nil,
  name: String.t() | nil
}
  • alias - The name of the value list for use in rules. Max length: 100.
  • expand - Specifies which fields in the response should be expanded.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • name - The human-readable name of the value list. Max length: 100.