StripeElixir.Params.SetupIntentCreateParams.AutomaticPaymentMethods (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.SetupIntentCreateParams.AutomaticPaymentMethods{
  allow_redirects: String.t() | nil,
  enabled: boolean() | nil
}
  • allow_redirects - Controls whether this SetupIntent will accept redirect-based payment methods.

Redirect-based payment methods may require your customer to be redirected to a payment method's app or site for authentication or additional steps. To confirm this SetupIntent, you may be required to provide a return_url to redirect customers back to your site after they authenticate or complete the setup. Possible values: always, never.

  • enabled - Whether this feature is enabled.