StripeElixir.Params.SetupIntentCreateParams.PaymentMethodData
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.SetupIntentCreateParams.PaymentMethodData{ acss_debit: map() | nil, affirm: map() | nil, afterpay_clearpay: map() | nil, alipay: map() | nil, allow_redisplay: String.t() | nil, alma: map() | nil, amazon_pay: map() | nil, au_becs_debit: map() | nil, bacs_debit: map() | nil, bancontact: map() | nil, billie: map() | nil, billing_details: map() | nil, blik: map() | nil, boleto: map() | nil, cashapp: map() | nil, crypto: map() | nil, customer_balance: map() | nil, eps: map() | nil, fpx: map() | nil, giropay: map() | nil, grabpay: map() | nil, ideal: map() | nil, interac_present: map() | nil, kakao_pay: map() | nil, klarna: map() | nil, konbini: map() | nil, kr_card: map() | nil, link: map() | nil, mb_way: map() | nil, metadata: map() | nil, mobilepay: map() | nil, multibanco: map() | nil, naver_pay: map() | nil, nz_bank_account: map() | nil, oxxo: map() | nil, p24: map() | nil, pay_by_bank: map() | nil, payco: map() | nil, paynow: map() | nil, paypal: map() | nil, payto: map() | nil, pix: map() | nil, promptpay: map() | nil, radar_options: map() | nil, revolut_pay: map() | nil, samsung_pay: map() | nil, satispay: map() | nil, sepa_debit: map() | nil, sofort: map() | nil, swish: map() | nil, twint: map() | nil, type: String.t() | nil, us_bank_account: map() | nil, wechat_pay: map() | nil, zip: map() | nil }
acss_debit- If this is anacss_debitPaymentMethod, this hash contains details about the ACSS Debit payment method.affirm- If this is anaffirmPaymentMethod, this hash contains details about the Affirm payment method.afterpay_clearpay- If this is anAfterpayClearpayPaymentMethod, this hash contains details about the AfterpayClearpay payment method.alipay- If this is anAlipayPaymentMethod, this hash contains details about the Alipay payment method.allow_redisplay- This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults tounspecified. Possible values:always,limited,unspecified.alma- If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.amazon_pay- If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.au_becs_debit- If this is anau_becs_debitPaymentMethod, this hash contains details about the bank account.bacs_debit- If this is abacs_debitPaymentMethod, this hash contains details about the Bacs Direct Debit bank account.bancontact- If this is abancontactPaymentMethod, this hash contains details about the Bancontact payment method.billie- If this is abilliePaymentMethod, this hash contains details about the Billie payment method.billing_details- Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.blik- If this is ablikPaymentMethod, this hash contains details about the BLIK payment method.boleto- If this is aboletoPaymentMethod, this hash contains details about the Boleto payment method.cashapp- If this is acashappPaymentMethod, this hash contains details about the Cash App Pay payment method.crypto- If this is a Crypto PaymentMethod, this hash contains details about the Crypto payment method.customer_balance- If this is acustomer_balancePaymentMethod, this hash contains details about the CustomerBalance payment method.eps- If this is anepsPaymentMethod, this hash contains details about the EPS payment method.fpx- If this is anfpxPaymentMethod, this hash contains details about the FPX payment method.giropay- If this is agiropayPaymentMethod, this hash contains details about the Giropay payment method.grabpay- If this is agrabpayPaymentMethod, this hash contains details about the GrabPay payment method.ideal- If this is anidealPaymentMethod, this hash contains details about the iDEAL payment method.interac_present- If this is aninterac_presentPaymentMethod, this hash contains details about the Interac Present payment method.kakao_pay- If this is akakao_payPaymentMethod, this hash contains details about the Kakao Pay payment method.klarna- If this is aklarnaPaymentMethod, this hash contains details about the Klarna payment method.konbini- If this is akonbiniPaymentMethod, this hash contains details about the Konbini payment method.kr_card- If this is akr_cardPaymentMethod, this hash contains details about the Korean Card payment method.link- If this is anLinkPaymentMethod, this hash contains details about the Link payment method.mb_way- If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.mobilepay- If this is amobilepayPaymentMethod, this hash contains details about the MobilePay payment method.multibanco- If this is amultibancoPaymentMethod, this hash contains details about the Multibanco payment method.naver_pay- If this is anaver_payPaymentMethod, this hash contains details about the Naver Pay payment method.nz_bank_account- If this is an nz_bank_account PaymentMethod, this hash contains details about the nz_bank_account payment method.oxxo- If this is anoxxoPaymentMethod, this hash contains details about the OXXO payment method.p24- If this is ap24PaymentMethod, this hash contains details about the P24 payment method.pay_by_bank- If this is apay_by_bankPaymentMethod, this hash contains details about the PayByBank payment method.payco- If this is apaycoPaymentMethod, this hash contains details about the PAYCO payment method.paynow- If this is apaynowPaymentMethod, this hash contains details about the PayNow payment method.paypal- If this is apaypalPaymentMethod, this hash contains details about the PayPal payment method.payto- If this is apaytoPaymentMethod, this hash contains details about the PayTo payment method.pix- If this is apixPaymentMethod, this hash contains details about the Pix payment method.promptpay- If this is apromptpayPaymentMethod, this hash contains details about the PromptPay payment method.radar_options- Options to configure Radar. See Radar Session for more information.revolut_pay- If this is arevolut_payPaymentMethod, this hash contains details about the Revolut Pay payment method.samsung_pay- If this is asamsung_payPaymentMethod, this hash contains details about the SamsungPay payment method.satispay- If this is asatispayPaymentMethod, this hash contains details about the Satispay payment method.sepa_debit- If this is asepa_debitPaymentMethod, this hash contains details about the SEPA debit bank account.sofort- If this is asofortPaymentMethod, this hash contains details about the SOFORT payment method.swish- If this is aswishPaymentMethod, this hash contains details about the Swish payment method.twint- If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.type- The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type. Possible values:acss_debit,affirm,afterpay_clearpay,alipay,alma,amazon_pay,au_becs_debit,bacs_debit,bancontact,billie,blik,boleto,cashapp,crypto,customer_balance,eps,fpx,giropay,grabpay,ideal,kakao_pay,klarna,konbini,kr_card,link,mb_way,mobilepay,multibanco,naver_pay,nz_bank_account,oxxo,p24,pay_by_bank,payco,paynow,paypal,payto,pix,promptpay,revolut_pay,samsung_pay,satispay,sepa_debit,sofort,swish,twint,us_bank_account,wechat_pay,zip.us_bank_account- If this is anus_bank_accountPaymentMethod, this hash contains details about the US bank account payment method.wechat_pay- If this is anwechat_payPaymentMethod, this hash contains details about the wechat_pay payment method.zip- If this is azipPaymentMethod, this hash contains details about the Zip payment method.