StripeElixir.Params.SetupIntentVerifyMicrodepositsParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for setup intent verify microdeposits.

Summary

Types

t()

@type t() :: %StripeElixir.Params.SetupIntentVerifyMicrodepositsParams{
  amounts: [integer()] | nil,
  descriptor_code: String.t() | nil,
  expand: [String.t()] | nil
}
  • amounts - Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.
  • descriptor_code - A six-character code starting with SM present in the microdeposit sent to the bank account. Max length: 5000.
  • expand - Specifies which fields in the response should be expanded.