StripeElixir.Params.SourceCreateParams.Mandate (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.SourceCreateParams.Mandate{
  acceptance: map() | nil,
  amount: map() | nil,
  currency: String.t() | nil,
  interval: String.t() | nil,
  notification_method: String.t() | nil
}
  • acceptance - The parameters required to notify Stripe of a mandate acceptance or refusal by the customer.
  • amount - The amount specified by the mandate. (Leave null for a mandate covering all amounts)
  • currency - The currency specified by the mandate. (Must match currency of the source) Format: ISO 4217 currency code.
  • interval - The interval of debits permitted by the mandate. Either one_time (just permitting a single debit), scheduled (with debits on an agreed schedule or for clearly-defined events), or variable(for debits with any frequency) Possible values: one_time, scheduled, variable. Max length: 5000.
  • notification_method - The method Stripe should use to notify the customer of upcoming debit instructions and/or mandate confirmation as required by the underlying debit network. Either email (an email is sent directly to the customer), manual (a source.mandate_notification event is sent to your webhooks endpoint and you should handle the notification) or none (the underlying debit network does not require any notification). Possible values: deprecated_none, email, manual, none, stripe_email. Max length: 5000.