StripeElixir.Params.SourceUpdateParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for source update.

Summary

Types

t()

@type t() :: %StripeElixir.Params.SourceUpdateParams{
  amount: integer() | nil,
  expand: [String.t()] | nil,
  mandate: map() | nil,
  metadata: map() | nil,
  owner: map() | nil,
  source_order: map() | nil
}
  • amount - Amount associated with the source.
  • expand - Specifies which fields in the response should be expanded.
  • mandate - Information about a mandate possibility attached to a source object (generally for bank debits) as well as its acceptance status.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • owner - Information about the owner of the payment instrument that may be used or required by particular source types.
  • source_order - Information about the items and shipping associated with the source. Required for transactional credit (for example Klarna) sources before you can charge it.