StripeElixir.Params.SubscriptionCreateParams.AddInvoiceItems (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.SubscriptionCreateParams.AddInvoiceItems{
  discounts: [map()] | nil,
  metadata: map() | nil,
  period: map() | nil,
  price: String.t() | nil,
  price_data: map() | nil,
  quantity: integer() | nil,
  tax_rates: map() | nil
}
  • discounts - The coupons to redeem into discounts for the item.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • period - The period associated with this invoice item. If not set, period.start.type defaults to max_item_period_start and period.end.type defaults to min_item_period_end.
  • price - The ID of the price object. One of price or price_data is required. Max length: 5000.
  • price_data - Data used to generate a new Price object inline. One of price or price_data is required.
  • quantity - Quantity for this item. Defaults to 1.
  • tax_rates - The tax rates which apply to the item. When set, the default_tax_rates do not apply to this item.