StripeElixir.Params.SubscriptionCreateParams.InvoiceSettings (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.SubscriptionCreateParams.InvoiceSettings{
  account_tax_ids: map() | nil,
  issuer: map() | nil
}
  • account_tax_ids - The account tax IDs associated with the subscription. Will be set on invoices generated by the subscription.
  • issuer - The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.