StripeElixir.Params.Tax.CalculationCreateParams.ShippingCost (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Tax.CalculationCreateParams.ShippingCost{
  amount: integer() | nil,
  shipping_rate: String.t() | nil,
  tax_behavior: String.t() | nil,
  tax_code: String.t() | nil
}
  • amount - A positive integer in the smallest currency unit representing the shipping charge. If tax_behavior=inclusive, then this amount includes taxes. Otherwise, taxes are calculated on top of this amount.
  • shipping_rate - If provided, the shipping rate's amount, tax_code and tax_behavior are used. If you provide a shipping rate, then you cannot pass the amount, tax_code, or tax_behavior parameters. Max length: 5000.
  • tax_behavior - Specifies whether the amount includes taxes. If tax_behavior=inclusive, then the amount includes taxes. Defaults to exclusive. Possible values: exclusive, inclusive.
  • tax_code - The tax code used to calculate tax on shipping. If not provided, the default shipping tax code from your Tax Settings is used.