Parameters for transaction retrieve.
Summary
Types
@type t() :: %StripeElixir.Params.Tax.TransactionRetrieveParams{ expand: [String.t()] | nil }
expand- Specifies which fields in the response should be expanded.
Parameters for transaction retrieve.
@type t() :: %StripeElixir.Params.Tax.TransactionRetrieveParams{ expand: [String.t()] | nil }
expand - Specifies which fields in the response should be expanded.