StripeElixir.Params.Terminal.ConnectionTokenCreateParams
(stripe_elixir v0.1.0)
Parameters for connection token create.
Summary
Types
@type t() :: %StripeElixir.Params.Terminal.ConnectionTokenCreateParams{ expand: [String.t()] | nil, location: String.t() | nil }
expand- Specifies which fields in the response should be expanded.location- The id of the location that this connection token is scoped to. If specified the connection token will only be usable with readers assigned to that location, otherwise the connection token will be usable with all readers. Note that location scoping only applies to internet-connected readers. For more details, see the docs on scoping connection tokens. Max length: 5000.