StripeElixir.Params.Terminal.ReaderConfirmPaymentIntentParams
(stripe_elixir v0.1.0)
Parameters for reader confirm payment intent.
Summary
Types
@type t() :: %StripeElixir.Params.Terminal.ReaderConfirmPaymentIntentParams{ confirm_config: map() | nil, expand: [String.t()] | nil, payment_intent: String.t() }
confirm_config- Configuration overrides for this confirmation, such as surcharge settings and return URL.expand- Specifies which fields in the response should be expanded.payment_intent- The ID of the PaymentIntent to confirm. Max length: 5000.