StripeElixir.Params.Terminal.ReaderSetReaderDisplayParams.Cart
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.Terminal.ReaderSetReaderDisplayParams.Cart{ currency: String.t() | nil, line_items: [map()] | nil, tax: integer() | nil, total: integer() | nil }
currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.line_items- Array of line items to display.tax- The amount of tax in the smallest currency unit.total- Total balance of cart due in the smallest currency unit.