StripeElixir.Params.TestHelpers.Issuing.AuthorizationReverseParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for authorization reverse.

Summary

Types

t()

@type t() :: %StripeElixir.Params.TestHelpers.Issuing.AuthorizationReverseParams{
  expand: [String.t()] | nil,
  reverse_amount: integer() | nil
}
  • expand - Specifies which fields in the response should be expanded.
  • reverse_amount - The amount to reverse from the authorization. If not provided, the full amount of the authorization will be reversed. This amount is in the authorization currency and in the smallest currency unit.