StripeElixir.Params.TestHelpers.Issuing.TransactionCreateForceCaptureParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for transaction create force capture.

Summary

Types

t()

@type t() ::
  %StripeElixir.Params.TestHelpers.Issuing.TransactionCreateForceCaptureParams{
    amount: integer(),
    card: String.t(),
    currency: String.t() | nil,
    expand: [String.t()] | nil,
    merchant_data: map() | nil,
    purchase_details: map() | nil
  }
  • amount - The total amount to attempt to capture. This amount is in the provided currency, or defaults to the cards currency, and in the smallest currency unit.
  • card - Card associated with this transaction. Max length: 5000.
  • currency - The currency of the capture. If not provided, defaults to the currency of the card. Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.
  • expand - Specifies which fields in the response should be expanded.
  • merchant_data - Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.
  • purchase_details - Additional purchase information that is optionally provided by the merchant.