StripeElixir.Params.TokenCreateParams.BankAccount (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.TokenCreateParams.BankAccount{
  account_holder_name: String.t() | nil,
  account_holder_type: String.t() | nil,
  account_number: String.t() | nil,
  account_type: String.t() | nil,
  country: String.t() | nil,
  currency: String.t() | nil,
  payment_method: String.t() | nil,
  routing_number: String.t() | nil
}
  • account_holder_name - The name of the person or business that owns the bank account. This field is required when attaching the bank account to a Customer object. Max length: 5000.
  • account_holder_type - The type of entity that holds the account. It can be company or individual. This field is required when attaching the bank account to a Customer object. Possible values: company, individual. Max length: 5000.
  • account_number - The account number for the bank account, in string form. Must be a checking account. Max length: 5000.
  • account_type - The bank account type. This can only be checking or savings in most countries. In Japan, this can only be futsu or toza. Possible values: checking, futsu, savings, toza. Max length: 5000.
  • country - The country in which the bank account is located. Max length: 5000.
  • currency - The currency the bank account is in. This must be a country/currency pairing that Stripe supports. Format: ISO 4217 currency code.
  • payment_method - The ID of a Payment Method with a type of us_bank_account. The Payment Method's bank account information will be copied and returned as a Bank Account Token. This parameter is exclusive with respect to all other parameters in the bank_account hash. You must include the top-level customer parameter if the Payment Method is attached to a Customer object. If the Payment Method is not attached to a Customer object, it will be consumed and cannot be used again. You may not use Payment Methods which were created by a Setup Intent with attach_to_self=true. Max length: 5000.
  • routing_number - The routing number, sort code, or other country-appropriate institution number for the bank account. For US bank accounts, this is required and should be the ACH routing number, not the wire routing number. If you are providing an IBAN for account_number, this field is not required. Max length: 5000.