StripeElixir.Params.TransferCreateParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for transfer create.

Summary

Types

t()

@type t() :: %StripeElixir.Params.TransferCreateParams{
  amount: integer() | nil,
  currency: String.t(),
  description: String.t() | nil,
  destination: String.t(),
  expand: [String.t()] | nil,
  metadata: map() | nil,
  source_transaction: String.t() | nil,
  source_type: String.t() | nil,
  transfer_group: String.t() | nil
}
  • amount - A positive integer in cents (or local equivalent) representing how much to transfer.
  • currency - Three-letter ISO code for currency in lowercase. Must be a supported currency. Format: ISO 4217 currency code.
  • description - An arbitrary string attached to the object. Often useful for displaying to users. Max length: 5000.
  • destination - The ID of a connected Stripe account. See the Connect documentation for details.
  • expand - Specifies which fields in the response should be expanded.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • source_transaction - You can use this parameter to transfer funds from a charge before they are added to your available balance. A pending balance will transfer immediately but the funds will not become available until the original charge becomes available. See the Connect documentation for details.
  • source_type - The source balance to use for this transfer. One of bank_account, card, or fpx. For most users, this will default to card. Possible values: bank_account, card, fpx. Max length: 5000.
  • transfer_group - A string that identifies this transaction as part of a group. See the Connect documentation for details.