StripeElixir.Params.Treasury.FinancialAccountCloseParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for financial account close.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Treasury.FinancialAccountCloseParams{
  expand: [String.t()] | nil,
  forwarding_settings: map() | nil
}
  • expand - Specifies which fields in the response should be expanded.
  • forwarding_settings - A different bank account where funds can be deposited/debited in order to get the closing FA's balance to $0