StripeElixir.Params.Treasury.FinancialAccountCreateParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for financial account create.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Treasury.FinancialAccountCreateParams{
  expand: [String.t()] | nil,
  features: map() | nil,
  metadata: map() | nil,
  nickname: map() | nil,
  platform_restrictions: map() | nil,
  supported_currencies: [String.t()]
}
  • expand - Specifies which fields in the response should be expanded.
  • features - Encodes whether a FinancialAccount has access to a particular feature. Stripe or the platform can control features via the requested field.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • nickname - The nickname for the FinancialAccount.
  • platform_restrictions - The set of functionalities that the platform can restrict on the FinancialAccount.
  • supported_currencies - The currencies the FinancialAccount can hold a balance in.