StripeElixir.Params.Treasury.FinancialAccountListParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for financial account list.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Treasury.FinancialAccountListParams{
  created: map() | nil,
  ending_before: String.t() | nil,
  expand: [String.t()] | nil,
  limit: integer() | nil,
  starting_after: String.t() | nil,
  status: String.t() | nil
}
  • created - Only return FinancialAccounts that were created during the given date interval.
  • ending_before - An object ID cursor for use in pagination. Max length: 5000.
  • expand - Specifies which fields in the response should be expanded.
  • limit - A limit ranging from 1 to 100 (defaults to 10).
  • starting_after - An object ID cursor for use in pagination. Max length: 5000.
  • status - Only return FinancialAccounts that have the given status: open or closed Possible values: closed, open.