StripeElixir.Params.Treasury.OutboundPaymentCreateParams.DestinationPaymentMethodData (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %StripeElixir.Params.Treasury.OutboundPaymentCreateParams.DestinationPaymentMethodData{
    billing_details: map() | nil,
    financial_account: String.t() | nil,
    metadata: map() | nil,
    type: String.t() | nil,
    us_bank_account: map() | nil
  }
  • billing_details - Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.
  • financial_account - Required if type is set to financial_account. The FinancialAccount ID to send funds to.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • type - The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type. Possible values: financial_account, us_bank_account.
  • us_bank_account - Required hash if type is set to us_bank_account.