StripeElixir.Params.V2.Core.AccountLinkCreateParams.UseCase
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.V2.Core.AccountLinkCreateParams.UseCase{ account_onboarding: map() | nil, account_update: map() | nil, type: String.t() | nil }
account_onboarding- Hash containing configuration options for an Account Link object that onboards a new account.account_update- Hash containing configuration options for an Account Link that updates an existing account.type- Open Enum. The type of Account Link the user is requesting. Possible values:account_onboarding,account_update.