Parameters for account update.
Summary
Types
@type t() :: %StripeElixir.Params.V2.Core.AccountUpdateParams{ account_token: String.t() | nil, configuration: map() | nil, contact_email: String.t() | nil, contact_phone: String.t() | nil, dashboard: String.t() | nil, defaults: map() | nil, display_name: String.t() | nil, identity: map() | nil, include: [String.t()] | nil, metadata: map() | nil }
account_token- The account token generated by the account token api.configuration- An Account Configuration which allows the Account to take on a key persona across Stripe products.contact_email- The default contact email address for the Account. Required when configuring the account as a merchant or recipient.contact_phone- The default contact phone for the Account.dashboard- A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account. Possible values:express,full,none.defaults- Default values to be used on Account Configurations.display_name- A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.identity- Information about the company, individual, and business represented by the Account.include- Additional fields to include in the response.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.