StripeElixir.Params.V2.Core.Accounts.PersonTokenCreateParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for person token create.

Summary

Types

t()

@type t() :: %StripeElixir.Params.V2.Core.Accounts.PersonTokenCreateParams{
  additional_addresses: [map()] | nil,
  additional_names: [map()] | nil,
  additional_terms_of_service: map() | nil,
  address: map() | nil,
  date_of_birth: map() | nil,
  documents: map() | nil,
  email: String.t() | nil,
  given_name: String.t() | nil,
  id_numbers: [map()] | nil,
  legal_gender: String.t() | nil,
  metadata: map() | nil,
  nationalities: [String.t()] | nil,
  phone: String.t() | nil,
  political_exposure: String.t() | nil,
  relationship: map() | nil,
  script_addresses: map() | nil,
  script_names: map() | nil,
  surname: String.t() | nil
}
  • additional_addresses - Additional addresses associated with the person.
  • additional_names - Additional names (e.g. aliases) associated with the person.
  • additional_terms_of_service - Attestations of accepted terms of service agreements.
  • address - The person's residential address.
  • date_of_birth - The person's date of birth.
  • documents - Documents that may be submitted to satisfy various informational requests.
  • email - Email.
  • given_name - The person's first name.
  • id_numbers - The identification numbers (e.g., SSN) associated with the person.
  • legal_gender - The person's gender (International regulations require either "male" or "female"). Possible values: female, male.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
  • nationalities - The nationalities (countries) this person is associated with.
  • phone - The phone number for this person.
  • political_exposure - The person's political exposure. Possible values: existing, none.
  • relationship - The relationship that this person has with the Account's business or legal entity.
  • script_addresses - The script addresses (e.g., non-Latin characters) associated with the person.
  • script_names - The script names (e.g. non-Latin characters) associated with the person.
  • surname - The person's last name.