StripeElixir.Params.V2.Core.Accounts.PersonTokenCreateParams.Relationship (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %StripeElixir.Params.V2.Core.Accounts.PersonTokenCreateParams.Relationship{
    authorizer: boolean() | nil,
    director: boolean() | nil,
    executive: boolean() | nil,
    legal_guardian: boolean() | nil,
    owner: boolean() | nil,
    percent_ownership: String.t() | nil,
    representative: boolean() | nil,
    title: String.t() | nil
  }
  • authorizer - Whether the individual is an authorizer of the Account's identity.
  • director - Indicates whether the person is a director of the associated legal entity.
  • executive - Indicates whether the person is an executive of the associated legal entity.
  • legal_guardian - Indicates whether the person is a legal guardian of the associated legal entity.
  • owner - Indicates whether the person is an owner of the associated legal entity.
  • percent_ownership - The percentage of ownership the person has in the associated legal entity. Format: decimal string.
  • representative - Indicates whether the person is a representative of the associated legal entity.
  • title - The title or position the person holds in the associated legal entity.