StripeElixir.Params.V2.Core.EventDestinationCreateParams
(stripe_elixir v0.1.0)
Parameters for event destination create.
Summary
Types
@type t() :: %StripeElixir.Params.V2.Core.EventDestinationCreateParams{ amazon_eventbridge: map() | nil, description: String.t() | nil, enabled_events: [String.t()], event_payload: String.t(), events_from: [String.t()] | nil, include: [String.t()] | nil, metadata: map() | nil, name: String.t(), snapshot_api_version: String.t() | nil, type: String.t(), webhook_endpoint: map() | nil }
amazon_eventbridge- Amazon EventBridge configuration.description- An optional description of what the event destination is used for.enabled_events- The list of events to enable for this endpoint.event_payload- Payload type of events being subscribed to. Possible values:snapshot,thin.events_from- Where events should be routed from.include- Additional fields to include in the response.metadata- Metadata.name- Event destination name.snapshot_api_version- If using the snapshot event payload, the API version events are rendered as.type- Event destination type. Possible values:amazon_eventbridge,webhook_endpoint.webhook_endpoint- Webhook endpoint configuration.