StripeElixir.Resources.AccountSession (stripe_elixir v0.1.0)

Copy Markdown View Source

ConnectEmbeddedMethodAccountSessionCreateMethodAccountSession

An AccountSession allows a Connect platform to grant access to a connected account in Connect embedded components.

We recommend that you create an AccountSession each time you need to display an embedded component to your user. Do not save AccountSessions to your database as they expire relatively quickly, and cannot be used more than once.

Related guide: Connect embedded components

Summary

Types

t()

@type t() :: %StripeElixir.Resources.AccountSession{
  account: String.t(),
  client_secret: String.t(),
  components: String.t() | map(),
  expires_at: integer(),
  livemode: boolean(),
  object: String.t()
}
  • account - The ID of the account the AccountSession was created for Max length: 5000.
  • client_secret - The client secret of this AccountSession. Used on the client to set up secure access to the given account.

The client secret can be used to provide access to account from your frontend. It should not be stored, logged, or exposed to anyone other than the connected account. Make sure that you have TLS enabled on any page that includes the client secret.

Refer to our docs to setup Connect embedded components and learn about how client_secret should be handled. Max length: 5000.

  • components - Expandable.
  • expires_at - The timestamp at which this AccountSession will expire. Format: Unix timestamp.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: account_session.

Functions

expandable_fields()

object_name()