StripeElixir.Resources.AdjustedForOverdraft (stripe_elixir v0.1.0)

Copy Markdown View Source

CustomerBalanceResourceCashBalanceTransactionResourceAdjustedForOverdraft

Summary

Types

t()

@type t() :: %StripeElixir.Resources.AdjustedForOverdraft{
  balance_transaction: String.t() | map(),
  linked_transaction: String.t() | map()
}
  • balance_transaction - The Balance Transaction that corresponds to funds taken out of your Stripe balance. Expandable.
  • linked_transaction - The Cash Balance Transaction that brought the customer balance negative, triggering the clawback of funds. Expandable.

Functions

expandable_fields()

object_name()