StripeElixir.Resources.Balance (stripe_elixir v0.1.0)

Copy Markdown View Source

Balance

This is an object representing your Stripe balance. You can retrieve it to see the balance currently on your Stripe account.

The top-level available and pending comprise your "payments balance."

Related guide: Balances and settlement time, Understanding Connect account balances

Summary

Types

t()

@type t() :: %StripeElixir.Resources.Balance{
  available: [map()],
  connect_reserved: [map()] | nil,
  instant_available: [map()] | nil,
  issuing: map() | nil,
  livemode: boolean(),
  object: String.t(),
  pending: [map()],
  refund_and_dispute_prefunding: map() | nil
}
  • available - Available funds that you can transfer or pay out automatically by Stripe or explicitly through the Transfers API or Payouts API. You can find the available balance for each currency and payment type in the source_types property. Expandable.
  • connect_reserved - Funds held due to negative balances on connected accounts where account.controller.requirement_collection is application, which includes Custom accounts. You can find the connect reserve balance for each currency and payment type in the source_types property. Expandable.
  • instant_available - Funds that you can pay out using Instant Payouts. Expandable.
  • issuing - Expandable.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: balance.
  • pending - Funds that aren't available in the balance yet. You can find the pending balance for each currency and each payment type in the source_types property. Expandable.
  • refund_and_dispute_prefunding - Expandable.

Functions

expandable_fields()

object_name()