StripeElixir.Resources.Capability (stripe_elixir v0.1.0)

Copy Markdown View Source

AccountCapability

This is an object representing a capability for a Stripe account.

Related guide: Account capabilities

Summary

Types

t()

@type t() :: %StripeElixir.Resources.Capability{
  account: String.t() | map(),
  future_requirements: map() | nil,
  id: String.t(),
  object: String.t(),
  requested: boolean(),
  requested_at: integer(),
  requirements: map() | nil,
  status: String.t()
}
  • account - The account for which the capability enables functionality. Expandable.
  • future_requirements - Expandable.
  • id - The identifier for the capability. Max length: 5000.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: capability.
  • requested - Whether the capability has been requested.
  • requested_at - Time at which the capability was requested. Measured in seconds since the Unix epoch. Format: Unix timestamp. Nullable.
  • requirements - Expandable.
  • status - The status of the capability. Possible values: active, inactive, pending, unrequested.

Functions

expandable_fields()

object_name()