DeletedBankAccount
Summary
Types
@type t() :: %StripeElixir.Resources.DeletedBankAccount{ currency: String.t() | nil, deleted: boolean(), id: String.t(), object: String.t() }
currency- Three-letter ISO code for the currency paid out to the bank account. Max length: 5000. Nullable.deleted- Always true for a deleted object Possible values:true.id- Unique identifier for the object. Max length: 5000.object- String representing the object's type. Objects of the same type share the same value. Possible values:bank_account.