StripeElixir.Resources.FinancialConnections.AccountOwner (stripe_elixir v0.1.0)

Copy Markdown View Source

BankConnectionsResourceOwner

Describes an owner of an account.

Summary

Types

t()

@type t() :: %StripeElixir.Resources.FinancialConnections.AccountOwner{
  email: String.t(),
  id: String.t(),
  name: String.t(),
  object: String.t(),
  ownership: String.t(),
  phone: String.t(),
  raw_address: String.t(),
  refreshed_at: integer()
}
  • email - The email address of the owner. Max length: 5000. Nullable.
  • id - Unique identifier for the object. Max length: 5000.
  • name - The full name of the owner. Max length: 5000.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: financial_connections.account_owner.
  • ownership - The ownership object that this owner belongs to. Max length: 5000.
  • phone - The raw phone number of the owner. Max length: 5000. Nullable.
  • raw_address - The raw physical address of the owner. Max length: 5000. Nullable.
  • refreshed_at - The timestamp of the refresh that updated this owner. Format: Unix timestamp. Nullable.

Functions

object_name()