StripeElixir.Resources.FinancialConnections.Transaction (stripe_elixir v0.1.0)

Copy Markdown View Source

BankConnectionsResourceTransaction

A Transaction represents a real transaction that affects a Financial Connections Account balance.

Summary

Types

t()

@type t() :: %StripeElixir.Resources.FinancialConnections.Transaction{
  account: String.t(),
  amount: integer(),
  currency: String.t(),
  description: String.t(),
  id: String.t(),
  livemode: boolean(),
  object: String.t(),
  status: String.t(),
  status_transitions: map(),
  transacted_at: integer(),
  transaction_refresh: String.t(),
  updated: integer()
}
  • account - The ID of the Financial Connections Account this transaction belongs to. Max length: 5000.
  • amount - The amount of this transaction, in cents (or local equivalent).
  • currency - Three-letter ISO currency code, in lowercase. Must be a supported currency. Max length: 5000.
  • description - The description of this transaction. Max length: 5000.
  • id - Unique identifier for the object. Max length: 5000.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: financial_connections.transaction.
  • status - The status of the transaction. Possible values: pending, posted, void.
  • status_transitions - Expandable.
  • transacted_at - Time at which the transaction was transacted. Measured in seconds since the Unix epoch. Format: Unix timestamp.
  • transaction_refresh - The token of the transaction refresh that last updated or created this transaction. Max length: 5000.
  • updated - Time at which the object was last updated. Measured in seconds since the Unix epoch. Format: Unix timestamp.

Functions

expandable_fields()

object_name()