StripeElixir.Resources.Identity.VerificationSession
(stripe_elixir v0.1.0)
GelatoVerificationSession
A VerificationSession guides you through the process of collecting and verifying the identities of your users. It contains details about the type of verification, such as what verification check to perform. Only create one VerificationSession for each verification in your system.
A VerificationSession transitions through multiple statuses throughout its lifetime as it progresses through the verification flow. The VerificationSession contains the user's verified data after verification checks are complete.
Related guide: The Verification Sessions API
Summary
Types
@type t() :: %StripeElixir.Resources.Identity.VerificationSession{ client_reference_id: String.t(), client_secret: String.t(), created: integer(), id: String.t(), last_error: map(), last_verification_report: String.t() | map(), livemode: boolean(), metadata: map(), object: String.t(), options: map(), provided_details: map() | nil, redaction: map(), related_customer: String.t(), related_customer_account: String.t(), related_person: map() | nil, status: String.t(), type: String.t(), url: String.t(), verification_flow: String.t() | nil, verified_outputs: map() | nil }
client_reference_id- A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems. Max length: 5000. Nullable.client_secret- The short-lived client secret used by Stripe.js to show a verification modal inside your app. This client secret expires after 24 hours and can only be used once. Don’t store it, log it, embed it in a URL, or expose it to anyone other than the user. Make sure that you have TLS enabled on any page that includes the client secret. Refer to our docs on passing the client secret to the frontend to learn more. Max length: 5000. Nullable.created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.id- Unique identifier for the object. Max length: 5000.last_error- If present, this property tells you the last error encountered when processing the verification. Nullable. Expandable.last_verification_report- ID of the most recent VerificationReport. Learn more about accessing detailed verification results. Nullable. Expandable.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.object- String representing the object's type. Objects of the same type share the same value. Possible values:identity.verification_session.options- A set of options for the session’s verification checks. Nullable. Expandable.provided_details- Details provided about the user being verified. These details may be shown to the user. Nullable. Expandable.redaction- Redaction status of this VerificationSession. If the VerificationSession is not redacted, this field will be null. Nullable. Expandable.related_customer- Customer ID Max length: 5000. Nullable.related_customer_account- The ID of the Account representing a customer. Max length: 5000. Nullable.related_person- Expandable.status- Status of this VerificationSession. Learn more about the lifecycle of sessions. Possible values:canceled,processing,requires_input,verified.type- The type of verification check to be performed. Possible values:document,id_number,verification_flow.url- The short-lived URL that you use to redirect a user to Stripe to submit their identity information. This URL expires after 48 hours and can only be used once. Don’t store it, log it, send it in emails or expose it to anyone other than the user. Refer to our docs on verifying identity documents to learn how to redirect users to Stripe. Max length: 5000. Nullable.verification_flow- The configuration token of a verification flow from the dashboard. Max length: 5000.verified_outputs- The user’s verified data. Nullable. Expandable.