StripeElixir.Resources.NextActionKonbiniDisplayDetails
(stripe_elixir v0.1.0)
payment_intent_next_action_konbini
Summary
Types
@type t() :: %StripeElixir.Resources.NextActionKonbiniDisplayDetails{ expires_at: integer(), hosted_voucher_url: String.t(), stores: String.t() | map() }
expires_at- The timestamp at which the pending Konbini payment expires. Format: Unix timestamp.hosted_voucher_url- The URL for the Konbini payment instructions page, which allows customers to view and print a Konbini voucher. Max length: 5000. Nullable.stores- Expandable.