StripeElixir.Resources.NextActionRedirectToUrl (stripe_elixir v0.1.0)

Copy Markdown View Source

SetupIntentNextActionRedirectToUrl

Summary

Types

t()

@type t() :: %StripeElixir.Resources.NextActionRedirectToUrl{
  return_url: String.t(),
  url: String.t()
}
  • return_url - If the customer does not exit their browser while authenticating, they will be redirected to this specified URL after completion. Max length: 5000. Nullable.
  • url - The URL you must redirect your customer to in order to authenticate. Max length: 5000. Nullable.

Functions

object_name()