Payout
A Payout object is created when you receive funds from Stripe, or when you
initiate a payout to either a bank account or debit card of a connected
Stripe account. You can retrieve individual payouts,
and list all payouts. Payouts are made on varying
schedules, depending on your country and
industry.
Related guide: Receiving payouts
Summary
Types
@type t() :: %StripeElixir.Resources.Payout{ amount: integer(), application_fee: String.t() | map(), application_fee_amount: integer(), arrival_date: integer(), automatic: boolean(), balance_transaction: String.t() | map(), created: integer(), currency: String.t(), description: String.t(), destination: map(), failure_balance_transaction: String.t() | map(), failure_code: String.t(), failure_message: String.t(), id: String.t(), livemode: boolean(), metadata: map(), method: String.t(), object: String.t(), original_payout: String.t() | map(), payout_method: String.t(), reconciliation_status: String.t(), reversed_by: String.t() | map(), source_type: String.t(), statement_descriptor: String.t(), status: String.t(), trace_id: map(), type: String.t() }
amount- The amount (in cents (or local equivalent)) that transfers to your bank account or debit card.application_fee- The application fee (if any) for the payout. See the Connect documentation for details. Nullable. Expandable.application_fee_amount- The amount of the application fee (if any) requested for the payout. See the Connect documentation for details. Nullable.arrival_date- Date that you can expect the payout to arrive in the bank. This factors in delays to account for weekends or bank holidays. Format: Unix timestamp.automatic- Returnstrueif the payout is created by an automated payout schedule andfalseif it's requested manually.balance_transaction- ID of the balance transaction that describes the impact of this payout on your account balance. Nullable. Expandable.created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.description- An arbitrary string attached to the object. Often useful for displaying to users. Max length: 5000. Nullable.destination- ID of the bank account or card the payout is sent to. Nullable. Expandable.failure_balance_transaction- If the payout fails or cancels, this is the ID of the balance transaction that reverses the initial balance transaction and returns the funds from the failed payout back in your balance. Nullable. Expandable.failure_code- Error code that provides a reason for a payout failure, if available. View our list of failure codes. Max length: 5000. Nullable.failure_message- Message that provides the reason for a payout failure, if available. Max length: 5000. Nullable.id- Unique identifier for the object. Max length: 5000.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Nullable.method- The method used to send this payout, which can bestandardorinstant.instantis supported for payouts to debit cards and bank accounts in certain countries. Learn more about bank support for Instant Payouts. Max length: 5000.object- String representing the object's type. Objects of the same type share the same value. Possible values:payout.original_payout- If the payout reverses another, this is the ID of the original payout. Nullable. Expandable.payout_method- ID of the v2 FinancialAccount the funds are sent to. Max length: 5000. Nullable.reconciliation_status- Ifcompleted, you can use the Balance Transactions API to list all balance transactions that are paid out in this payout. Possible values:completed,in_progress,not_applicable.reversed_by- If the payout reverses, this is the ID of the payout that reverses this payout. Nullable. Expandable.source_type- The source balance this payout came from, which can be one of the following:card,fpx, orbank_account. Max length: 5000.statement_descriptor- Extra information about a payout that displays on the user's bank statement. Max length: 5000. Nullable.status- Current status of the payout:paid,pending,in_transit,canceledorfailed. A payout ispendinguntil it's submitted to the bank, when it becomesin_transit. The status changes topaidif the transaction succeeds, or tofailedorcanceled(within 5 business days). Some payouts that fail might initially show aspaid, then change tofailed. Max length: 5000.trace_id- A value that generates from the beneficiary's bank that allows users to track payouts with their bank. Banks might call this a "reference number" or something similar. Nullable. Expandable.type- Can bebank_accountorcard. Possible values:bank_account,card.