Plan
You can now model subscriptions more flexibly using the Prices API. It replaces the Plans API and is backwards compatible to simplify your migration.
Plans define the base price, currency, and billing cycle for recurring purchases of products. Products help you track inventory or provisioning, and plans help you track pricing. Different physical goods or levels of service should be represented by products, and pricing options should be represented by plans. This approach lets you change prices without having to change your provisioning scheme.
For example, you might have a single "gold" product that has plans for $10/month, $100/year, €9/month, and €90/year.
Related guides: Set up a subscription and more about products and prices.
Summary
Types
@type t() :: %StripeElixir.Resources.Plan{ active: boolean(), amount: integer(), amount_decimal: String.t(), billing_scheme: String.t(), created: integer(), currency: String.t(), id: String.t(), interval: String.t(), interval_count: integer(), livemode: boolean(), metadata: map(), meter: String.t(), nickname: String.t(), object: String.t(), product: map(), tiers: [map()] | nil, tiers_mode: String.t(), transform_usage: map(), trial_period_days: integer(), usage_type: String.t() }
active- Whether the plan can be used for new purchases.amount- The unit amount in cents (or local equivalent) to be charged, represented as a whole integer if possible. Only set ifbilling_scheme=per_unit. Nullable.amount_decimal- The unit amount in cents (or local equivalent) to be charged, represented as a decimal string with at most 12 decimal places. Only set ifbilling_scheme=per_unit. Format: decimal string. Nullable.billing_scheme- Describes how to compute the price per period. Eitherper_unitortiered.per_unitindicates that the fixed amount (specified inamount) will be charged per unit inquantity(for plans withusage_type=licensed), or per unit of total usage (for plans withusage_type=metered).tieredindicates that the unit pricing will be computed using a tiering strategy as defined using thetiersandtiers_modeattributes. Possible values:per_unit,tiered.created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.id- Unique identifier for the object. Max length: 5000.interval- The frequency at which a subscription is billed. One ofday,week,monthoryear. Possible values:day,month,week,year.interval_count- The number of intervals (specified in theintervalattribute) between subscription billings. For example,interval=monthandinterval_count=3bills every 3 months.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Nullable.meter- The meter tracking the usage of a metered price Max length: 5000. Nullable.nickname- A brief description of the plan, hidden from customers. Max length: 5000. Nullable.object- String representing the object's type. Objects of the same type share the same value. Possible values:plan.product- The product whose pricing this plan determines. Nullable. Expandable.tiers- Each element represents a pricing tier. This parameter requiresbilling_schemeto be set totiered. See also the documentation forbilling_scheme. Expandable.tiers_mode- Defines if the tiering price should begraduatedorvolumebased. Involume-based tiering, the maximum quantity within a period determines the per unit price. Ingraduatedtiering, pricing can change as the quantity grows. Possible values:graduated,volume. Nullable.transform_usage- Apply a transformation to the reported usage or set quantity before computing the amount billed. Cannot be combined withtiers. Nullable. Expandable.trial_period_days- Default number of trial days when subscribing a customer to this plan usingtrial_from_plan=true. Nullable.usage_type- Configures how the quantity per period should be determined. Can be eithermeteredorlicensed.licensedautomatically bills thequantityset when adding it to a subscription.meteredaggregates the total usage based on usage records. Defaults tolicensed. Possible values:licensed,metered.