StripeElixir.Resources.ProductFeature (stripe_elixir v0.1.0)

Copy Markdown View Source

ProductFeature

A product_feature represents an attachment between a feature and a product. When a product is purchased that has a feature attached, Stripe will create an entitlement to the feature for the purchasing customer.

Summary

Types

t()

@type t() :: %StripeElixir.Resources.ProductFeature{
  entitlement_feature: String.t() | map(),
  id: String.t(),
  livemode: boolean(),
  object: String.t()
}
  • entitlement_feature - Expandable.
  • id - Unique identifier for the object. Max length: 5000.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: product_feature.

Functions

expandable_fields()

object_name()