StripeElixir.Resources.Tax.Association (stripe_elixir v0.1.0)

Copy Markdown View Source

TaxProductResourceTaxAssociation

A Tax Association exposes the Tax Transactions that Stripe attempted to create on your behalf based on the PaymentIntent input

Summary

Types

t()

@type t() :: %StripeElixir.Resources.Tax.Association{
  calculation: String.t(),
  id: String.t(),
  object: String.t(),
  payment_intent: String.t(),
  tax_transaction_attempts: [map()]
}
  • calculation - The Tax Calculation that was included in PaymentIntent. Max length: 5000.
  • id - Unique identifier for the object. Max length: 5000.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: tax.association.
  • payment_intent - The PaymentIntent that this Tax Association is tracking. Max length: 5000.
  • tax_transaction_attempts - Information about the tax transactions linked to this payment intent Nullable. Expandable.

Functions

expandable_fields()

object_name()