StripeElixir.Resources.Tax.Calculation (stripe_elixir v0.1.0)

Copy Markdown View Source

TaxProductResourceTaxCalculation

A Tax Calculation allows you to calculate the tax to collect from your customer.

Related guide: Calculate tax in your custom payment flow

Summary

Types

t()

@type t() :: %StripeElixir.Resources.Tax.Calculation{
  amount_total: integer(),
  currency: String.t(),
  customer: String.t(),
  customer_details: map(),
  expires_at: integer(),
  id: String.t(),
  line_items: map() | nil,
  livemode: boolean(),
  object: String.t(),
  ship_from_details: map(),
  shipping_cost: map(),
  tax_amount_exclusive: integer(),
  tax_amount_inclusive: integer(),
  tax_breakdown: [map()],
  tax_date: integer()
}
  • amount_total - Total amount after taxes in the smallest currency unit.
  • currency - Three-letter ISO currency code, in lowercase. Must be a supported currency. Max length: 5000.
  • customer - The ID of an existing Customer used for the resource. Max length: 5000. Nullable.
  • customer_details - Expandable.
  • expires_at - Timestamp of date at which the tax calculation will expire. Format: Unix timestamp. Nullable.
  • id - Unique identifier for the calculation. Max length: 5000. Nullable.
  • line_items - The list of items the customer is purchasing. Nullable. Expandable.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: tax.calculation.
  • ship_from_details - The details of the ship from location, such as the address. Nullable. Expandable.
  • shipping_cost - The shipping cost details for the calculation. Nullable. Expandable.
  • tax_amount_exclusive - The amount of tax to be collected on top of the line item prices.
  • tax_amount_inclusive - The amount of tax already included in the line item prices.
  • tax_breakdown - Breakdown of individual tax amounts that add up to the total. Expandable.
  • tax_date - Timestamp of date at which the tax rules and rates in effect applies for the calculation. Format: Unix timestamp.

Functions

expandable_fields()

object_name()