StripeElixir.Resources.TaxDeductedAtSource (stripe_elixir v0.1.0)

Copy Markdown View Source

TaxDeductedAtSource

Summary

Types

t()

@type t() :: %StripeElixir.Resources.TaxDeductedAtSource{
  id: String.t(),
  object: String.t(),
  period_end: integer(),
  period_start: integer(),
  tax_deduction_account_number: String.t()
}
  • id - Unique identifier for the object. Max length: 5000.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: tax_deducted_at_source.
  • period_end - The end of the invoicing period. This TDS applies to Stripe fees collected during this invoicing period. Format: Unix timestamp.
  • period_start - The start of the invoicing period. This TDS applies to Stripe fees collected during this invoicing period. Format: Unix timestamp.
  • tax_deduction_account_number - The TAN that was supplied to Stripe when TDS was assessed Max length: 5000.

Functions

object_name()