StripeElixir.Resources.Terminal.ConnectionToken (stripe_elixir v0.1.0)

Copy Markdown View Source

TerminalConnectionToken

A Connection Token is used by the Stripe Terminal SDK to connect to a reader.

Related guide: Fleet management

Summary

Types

t()

@type t() :: %StripeElixir.Resources.Terminal.ConnectionToken{
  location: String.t() | nil,
  object: String.t(),
  secret: String.t()
}
  • location - The id of the location that this connection token is scoped to. Note that location scoping only applies to internet-connected readers. For more details, see the docs on scoping connection tokens. Max length: 5000.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: terminal.connection_token.
  • secret - Your application should pass this token to the Stripe Terminal SDK. Max length: 5000.

Functions

object_name()