StripeElixir.Resources.V2.Billing.MeterEventAdjustment
(stripe_elixir v0.1.0)
Meter Event Adjustment
Summary
Types
@type t() :: %StripeElixir.Resources.V2.Billing.MeterEventAdjustment{ cancel: map(), created: String.t(), event_name: String.t(), id: String.t(), livemode: boolean(), object: String.t(), status: String.t(), type: String.t() }
cancel- Specifies which event to cancel.created- The time the adjustment was created. Format: date-time.event_name- The name of the meter event. Corresponds with theevent_namefield on a meter.id- The unique id of this meter event adjustment.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.object- String representing the object's type. Objects of the same type share the same value of the object field. Possible values:v2.billing.meter_event_adjustment.status- Open Enum. The meter event adjustment’s status. Possible values:complete,pending.type- Open Enum. Specifies whether to cancel a single event or a range of events for a time period. Time period cancellation is not supported yet. Possible values:cancel.