ConnectEmbeddedMethodAccountSessionCreateMethodAccountSession
An AccountSession allows a Connect platform to grant access to a connected account in Connect embedded components.
We recommend that you create an AccountSession each time you need to display an embedded component to your user. Do not save AccountSessions to your database as they expire relatively quickly, and cannot be used more than once.
Related guide: Connect embedded components
Summary
Functions
Create an Account Session
Functions
@spec create(StripeElixir.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Create an Account Session
Creates a AccountSession object that includes a single-use token that the platform can use on their front-end to grant client-side API access.