StripeElixir.Services.ApplicationFeeService (stripe_elixir v0.1.0)

Copy Markdown View Source

PlatformFee

Summary

Functions

list(client, params \\ %{}, opts \\ [])

@spec list(StripeElixir.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

List all application fees

Returns a list of application fees you’ve previously collected. The application fees are returned in sorted order, with the most recent fees appearing first.

retrieve(client, id, params \\ %{}, opts \\ [])

@spec retrieve(StripeElixir.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Retrieve an application fee

Retrieves the details of an application fee that your account has collected. The same information is returned when refunding the application fee.