StripeElixir.Services.Billing.MeterEventService (stripe_elixir v0.1.0)

Copy Markdown View Source

BillingMeterEvent

Meter events represent actions that customers take in your system. You can use meter events to bill a customer based on their usage. Meter events are associated with billing meters, which define both the contents of the event’s payload and how to aggregate those events.

Summary

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(StripeElixir.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Create a billing meter event

Creates a billing meter event.