StripeElixir.Services.BillingPortal.ConfigurationService (stripe_elixir v0.1.0)

Copy Markdown View Source

PortalConfiguration

A portal configuration describes the functionality and behavior you embed in a portal session. Related guide: Configure the customer portal.

Summary

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(StripeElixir.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Create a portal configuration

Creates a configuration that describes the functionality and behavior of a PortalSession

list(client, params \\ %{}, opts \\ [])

@spec list(StripeElixir.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

List portal configurations

Returns a list of configurations that describe the functionality of the customer portal.

retrieve(client, configuration, params \\ %{}, opts \\ [])

@spec retrieve(StripeElixir.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Retrieve a portal configuration

Retrieves a configuration that describes the functionality of the customer portal.

update(client, configuration, params \\ %{}, opts \\ [])

@spec update(StripeElixir.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Update a portal configuration

Updates a configuration that describes the functionality of the customer portal.