StripeElixir.Services.Climate.ProductService (stripe_elixir v0.1.0)

Copy Markdown View Source

ClimateRemovalsProducts

A Climate product represents a type of carbon removal unit available for reservation. You can retrieve it to see the current price and availability.

Summary

Functions

list(client, params \\ %{}, opts \\ [])

@spec list(StripeElixir.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

List products

Lists all available Climate product objects.

retrieve(client, product, params \\ %{}, opts \\ [])

@spec retrieve(StripeElixir.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Retrieve a product

Retrieves the details of a Climate product with the given ID.