StripeElixir.Services.CustomerFundingInstructionsService (stripe_elixir v0.1.0)

Copy Markdown View Source

CustomerFundingInstructions API operations.

Summary

Functions

Create or retrieve funding instructions for a customer cash balance

Functions

create_funding_instructions(client, customer, params \\ %{}, opts \\ [])

@spec create_funding_instructions(
  StripeElixir.Client.t(),
  String.t(),
  map(),
  keyword()
) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Create or retrieve funding instructions for a customer cash balance

Retrieve funding instructions for a customer cash balance. If funding instructions do not yet exist for the customer, new funding instructions will be created. If funding instructions have already been created for a given customer, the same funding instructions will be retrieved. In other words, we will return the same funding instructions each time.