StripeElixir.Services.InvoiceRenderingTemplateService
(stripe_elixir v0.1.0)
InvoiceRenderingTemplate
Invoice Rendering Templates are used to configure how invoices are rendered on surfaces like the PDF. Invoice Rendering Templates can be created from within the Dashboard, and they can be used over the API when creating invoices.
Summary
Functions
Archive an invoice rendering template
List all invoice rendering templates
Retrieve an invoice rendering template
Unarchive an invoice rendering template
Functions
@spec archive(StripeElixir.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Archive an invoice rendering template
Updates the status of an invoice rendering template to ‘archived’ so no new Stripe objects (customers, invoices, etc.) can reference it. The template can also no longer be updated. However, if the template is already set on a Stripe object, it will continue to be applied on invoices generated by it.
@spec list(StripeElixir.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
List all invoice rendering templates
List all templates, ordered by creation date, with the most recently created template appearing first.
@spec retrieve(StripeElixir.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Retrieve an invoice rendering template
Retrieves an invoice rendering template with the given ID. It by default returns the latest version of the template. Optionally, specify a version to see previous versions.
@spec unarchive(StripeElixir.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Unarchive an invoice rendering template
Unarchive an invoice rendering template so it can be used on new Stripe objects again.