StripeElixir.Services.OAuthService (stripe_elixir v0.1.0)

Copy Markdown View Source

OAuth API operations for Stripe Connect.

Summary

Functions

Build an OAuth authorize URL for Stripe Connect.

Deauthorize a connected account.

Exchange an authorization code for an access token, or refresh a token.

Functions

authorize_url(client, params \\ %{}, opts \\ [])

Build an OAuth authorize URL for Stripe Connect.

Options

  • :express - Use Express account flow (/express/oauth/authorize)

deauthorize(client, params \\ %{}, opts \\ [])

Deauthorize a connected account.

token(client, params \\ %{}, opts \\ [])

Exchange an authorization code for an access token, or refresh a token.