StripeElixir.Services.QuoteComputedUpfrontLineItemsService (stripe_elixir v0.1.0)

Copy Markdown View Source

QuoteComputedUpfrontLineItems API operations.

Summary

Functions

list_computed_upfront_line_items(client, quote, params \\ %{}, opts \\ [])

@spec list_computed_upfront_line_items(
  StripeElixir.Client.t(),
  String.t(),
  map(),
  keyword()
) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Retrieve a quote's upfront line items

When retrieving a quote, there is an includable computed.upfront.line_items property containing the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of upfront line items.