ShippingRate
Shipping rates describe the price of shipping presented to your customers and applied to a purchase. For more information, see Charge for shipping.
Summary
Functions
Create a shipping rate
List all shipping rates
Retrieve a shipping rate
Update a shipping rate
Functions
@spec create(StripeElixir.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Create a shipping rate
Creates a new shipping rate object.
@spec list(StripeElixir.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
List all shipping rates
Returns a list of your shipping rates.
@spec retrieve(StripeElixir.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Retrieve a shipping rate
Returns the shipping rate object with the given ID.
@spec update(StripeElixir.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Update a shipping rate
Updates an existing shipping rate object.