StripeElixir.Services.Tax.AssociationService (stripe_elixir v0.1.0)

Copy Markdown View Source

TaxProductResourceTaxAssociation

A Tax Association exposes the Tax Transactions that Stripe attempted to create on your behalf based on the PaymentIntent input

Summary

Functions

find(client, params \\ %{}, opts \\ [])

@spec find(StripeElixir.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Find a Tax Association

Finds a tax association object by PaymentIntent id.