StripeElixir.Services.TaxCodeService (stripe_elixir v0.1.0)

Copy Markdown View Source

TaxProductResourceTaxCode

Tax codes classify goods and services for tax purposes.

Summary

Functions

list(client, params \\ %{}, opts \\ [])

@spec list(StripeElixir.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

List all tax codes

A list of all tax codes available to add to Products in order to allow specific tax calculations.

retrieve(client, id, params \\ %{}, opts \\ [])

@spec retrieve(StripeElixir.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Retrieve a tax code

Retrieves the details of an existing tax code. Supply the unique tax code ID and Stripe will return the corresponding tax code information.