StripeElixir.Services.TestHelpers.Issuing.PersonalizationDesignService (stripe_elixir v0.1.0)

Copy Markdown View Source

PersonalizationDesign API operations.

Summary

Functions

activate(client, personalization_design, params \\ %{}, opts \\ [])

@spec activate(StripeElixir.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Activate a testmode personalization design

Updates the status of the specified testmode personalization design object to active.

deactivate(client, personalization_design, params \\ %{}, opts \\ [])

@spec deactivate(StripeElixir.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Deactivate a testmode personalization design

Updates the status of the specified testmode personalization design object to inactive.

reject(client, personalization_design, params \\ %{}, opts \\ [])

@spec reject(StripeElixir.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Reject a testmode personalization design

Updates the status of the specified testmode personalization design object to rejected.