StripeElixir.Services.Treasury.OutboundPaymentService
(stripe_elixir v0.1.0)
TreasuryOutboundPaymentsResourceOutboundPayment
Use OutboundPayments to send funds to another party's external bank account or FinancialAccount. To send money to an account belonging to the same user, use an OutboundTransfer.
Simulate OutboundPayment state changes with the /v1/test_helpers/treasury/outbound_payments endpoints. These methods can only be called on test mode objects.
Related guide: Moving money with Treasury using OutboundPayment objects
Summary
Functions
Cancel an OutboundPayment
Create an OutboundPayment
List all OutboundPayments
Retrieve an OutboundPayment
Functions
@spec cancel(StripeElixir.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Cancel an OutboundPayment
Cancel an OutboundPayment.
@spec create(StripeElixir.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Create an OutboundPayment
Creates an OutboundPayment.
@spec list(StripeElixir.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
List all OutboundPayments
Returns a list of OutboundPayments sent from the specified FinancialAccount.
@spec retrieve(StripeElixir.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Retrieve an OutboundPayment
Retrieves the details of an existing OutboundPayment by passing the unique OutboundPayment ID from either the OutboundPayment creation request or OutboundPayment list.