Webhook event for benefit_grant.cycled.
Sent when a benefit grant is cycled, meaning the related subscription has been renewed for another period.
Discord & Slack support: Basic
The data field contains a PolarExpress.Schemas.BenefitGrantWebhook struct.
Summary
Functions
Returns the event type string.
Types
@type t() :: %PolarExpress.Events.BenefitGrantCycled{ data: PolarExpress.Schemas.BenefitGrantWebhook.t(), timestamp: String.t(), type: String.t() }
type- Always"benefit_grant.cycled".data- The event payload. SeePolarExpress.Schemas.BenefitGrantWebhook.timestamp- ISO 8601 timestamp of when the event occurred.
Functions
@spec event_type() :: String.t()
Returns the event type string.