Webhook event for customer_seat.assigned.
Sent when a new customer seat is assigned.
This event is triggered when a seat is assigned to a customer by the organization. The customer will receive an invitation email to claim the seat.
The data field contains a PolarExpress.Schemas.CustomerSeat struct.
Summary
Functions
Returns the event type string.
Types
@type t() :: %PolarExpress.Events.CustomerSeatAssigned{ data: PolarExpress.Schemas.CustomerSeat.t(), timestamp: String.t(), type: String.t() }
type- Always"customer_seat.assigned".data- The event payload. SeePolarExpress.Schemas.CustomerSeat.timestamp- ISO 8601 timestamp of when the event occurred.
Functions
@spec event_type() :: String.t()
Returns the event type string.