Webhook event for customer_seat.revoked.
Sent when a customer seat is revoked.
This event is triggered when access to a seat is revoked, either manually by the organization or automatically when a subscription is canceled.
The data field contains a PolarExpress.Schemas.CustomerSeat struct.
Summary
Functions
Returns the event type string.
Types
@type t() :: %PolarExpress.Events.CustomerSeatRevoked{ data: PolarExpress.Schemas.CustomerSeat.t(), timestamp: String.t(), type: String.t() }
type- Always"customer_seat.revoked".data- The event payload. SeePolarExpress.Schemas.CustomerSeat.timestamp- ISO 8601 timestamp of when the event occurred.
Functions
@spec event_type() :: String.t()
Returns the event type string.