Webhook event for customer.updated.
Sent when a customer is updated.
This event is fired when the customer details are updated.
If you want to be notified when a customer subscription or benefit state changes, you should listen to the customer_state_changed event.
Discord & Slack support: Basic
The data field contains a PolarExpress.Schemas.Customer struct.
Summary
Functions
Returns the event type string.
Types
@type t() :: %PolarExpress.Events.CustomerUpdated{ data: PolarExpress.Schemas.Customer.t(), timestamp: String.t(), type: String.t() }
type- Always"customer.updated".data- The event payload. SeePolarExpress.Schemas.Customer.timestamp- ISO 8601 timestamp of when the event occurred.
Functions
@spec event_type() :: String.t()
Returns the event type string.