Webhook event for member.deleted.
Sent when a member is deleted.
This event is triggered when a member is removed from a customer. Any active seats assigned to the member will be automatically revoked.
Discord & Slack support: Basic
The data field contains a PolarExpress.Schemas.Member struct.
Summary
Functions
Returns the event type string.
Types
@type t() :: %PolarExpress.Events.MemberDeleted{ data: PolarExpress.Schemas.Member.t(), timestamp: String.t(), type: String.t() }
type- Always"member.deleted".data- The event payload. SeePolarExpress.Schemas.Member.timestamp- ISO 8601 timestamp of when the event occurred.
Functions
@spec event_type() :: String.t()
Returns the event type string.