Webhook event for member.updated.
Sent when a member is updated.
This event is triggered when member details are updated, such as their name or role within the customer.
Discord & Slack support: Basic
The data field contains a PolarExpress.Schemas.Member struct.
Summary
Functions
Returns the event type string.
Types
@type t() :: %PolarExpress.Events.MemberUpdated{ data: PolarExpress.Schemas.Member.t(), timestamp: String.t(), type: String.t() }
type- Always"member.updated".data- The event payload. SeePolarExpress.Schemas.Member.timestamp- ISO 8601 timestamp of when the event occurred.
Functions
@spec event_type() :: String.t()
Returns the event type string.