Webhook event for order.created.
Sent when a new order is created.
A new order is created when:
- A customer purchases a one-time product. In this case,
billing_reasonis set topurchase. - A customer starts a subscription. In this case,
billing_reasonis set tosubscription_create. - A subscription is renewed. In this case,
billing_reasonis set tosubscription_cycle. - A subscription is upgraded or downgraded with an immediate proration invoice. In this case,
billing_reasonis set tosubscription_update.
[!WARNING] The order might not be paid yet, so the
statusfield might bepending.
Discord & Slack support: Full
The data field contains a PolarExpress.Schemas.Order struct.
Summary
Functions
Returns the event type string.
Types
@type t() :: %PolarExpress.Events.OrderCreated{ data: PolarExpress.Schemas.Order.t(), timestamp: String.t(), type: String.t() }
type- Always"order.created".data- The event payload. SeePolarExpress.Schemas.Order.timestamp- ISO 8601 timestamp of when the event occurred.
Functions
@spec event_type() :: String.t()
Returns the event type string.