Webhook event for subscription.active.
Sent when a subscription becomes active, whether because it's a new paid subscription or because payment was recovered.
Discord & Slack support: Full
The data field contains a PolarExpress.Schemas.Subscription struct.
Summary
Functions
Returns the event type string.
Types
@type t() :: %PolarExpress.Events.SubscriptionActive{ data: PolarExpress.Schemas.Subscription.t(), timestamp: String.t(), type: String.t() }
type- Always"subscription.active".data- The event payload. SeePolarExpress.Schemas.Subscription.timestamp- ISO 8601 timestamp of when the event occurred.
Functions
@spec event_type() :: String.t()
Returns the event type string.