Webhook event for subscription.created.
Sent when a new subscription is created.
When this event occurs, the subscription status might not be active yet, as we can still have to wait for the first payment to be processed.
Discord & Slack support: Full
The data field contains a PolarExpress.Schemas.Subscription struct.
Summary
Functions
Returns the event type string.
Types
@type t() :: %PolarExpress.Events.SubscriptionCreated{ data: PolarExpress.Schemas.Subscription.t(), timestamp: String.t(), type: String.t() }
type- Always"subscription.created".data- The event payload. SeePolarExpress.Schemas.Subscription.timestamp- ISO 8601 timestamp of when the event occurred.
Functions
@spec event_type() :: String.t()
Returns the event type string.