Organizations
Organizations API operations.
Summary
Types
@type t() :: %PolarExpress.Resources.Organizations{ allow_customer_updates: boolean() | nil, avatar_url: term() | nil, created_at: String.t() | nil, customer_email_settings: map() | nil, customer_portal_settings: map() | nil, default_presentment_currency: String.t() | nil, details_submitted_at: term() | nil, email: term() | nil, feature_settings: term() | nil, id: String.t() | nil, modified_at: term() | nil, name: String.t() | nil, notification_settings: map() | nil, proration_behavior: map() | nil, slug: String.t() | nil, socials: [map()] | nil, status: map() | nil, subscription_settings: map() | nil, website: term() | nil }
allow_customer_updates- Whether customers can update their subscriptions from the customer portal.avatar_url- Avatar URL shown in checkout, customer portal, emails etc.created_at- Creation timestamp of the object. Format: date-time.customer_email_settings- Settings related to customer emailscustomer_portal_settings- Settings related to the customer portaldefault_presentment_currency- Default presentment currency. Used as fallback in checkout and customer portal, if the customer's local currency is not available.details_submitted_at- When the business details were submitted.email- Public support email.feature_settings- Organization feature settingsid- The ID of the object. Format: uuid4.modified_at- Last modification timestamp of the object.name- Organization name shown in checkout, customer portal, emails etc.notification_settings- Settings related to notificationsproration_behavior- Proration behavior applied when customer updates their subscription from the portal.slug- Unique organization slug in checkout, customer portal and credit card statements.socials- Links to social profiles.status- Current organization statussubscription_settings- Settings related to subscriptions managementwebsite- Official website of the organization.