AttachedCustomField
Schema of a custom field attached to a resource.
Summary
Types
@type t() :: %PolarExpress.Schemas.AttachedCustomField{ custom_field: PolarExpress.Schemas.CustomField.t() | nil, custom_field_id: String.t() | nil, order: integer() | nil, required: boolean() | nil }
custom_fieldcustom_field_id- ID of the custom field. Format: uuid4.order- Order of the custom field in the resource.required- Whether the value is required for this custom field.