PolarExpress.Schemas.CheckoutDiscountFixedRepeatDuration
(polar_express v0.1.5)
CheckoutDiscountFixedRepeatDuration
Schema for a fixed amount discount that is applied on every invoice for a certain number of months.
Summary
Types
@type t() :: %PolarExpress.Schemas.CheckoutDiscountFixedRepeatDuration{ amount: integer() | nil, code: String.t() | nil, currency: String.t() | nil, duration: PolarExpress.Schemas.DiscountDuration.t() | nil, duration_in_months: integer() | nil, id: String.t() | nil, name: String.t() | nil, type: PolarExpress.Schemas.DiscountType.t() | nil }
amountcode- Nullable.currencydurationduration_in_monthsid- The ID of the object. Format: uuid4.nametype