PolarExpress.Schemas.CheckoutDiscountPercentageRepeatDuration
(polar_express v0.1.5)
CheckoutDiscountPercentageRepeatDuration
Schema for a percentage discount that is applied on every invoice for a certain number of months.
Summary
Types
@type t() :: %PolarExpress.Schemas.CheckoutDiscountPercentageRepeatDuration{ basis_points: integer() | nil, code: String.t() | nil, duration: PolarExpress.Schemas.DiscountDuration.t() | nil, duration_in_months: integer() | nil, id: String.t() | nil, name: String.t() | nil, type: PolarExpress.Schemas.DiscountType.t() | nil }
basis_points- Discount percentage in basis points. A basis point is 1/100th of a percent. For example, 1000 basis points equals a 10% discount.code- Nullable.durationduration_in_monthsid- The ID of the object. Format: uuid4.nametype