CustomerOrderConfirmPayment
Schema to confirm a retry payment using either a saved payment method or a new confirmation token.
Summary
Types
@type t() :: %PolarExpress.Schemas.CustomerOrderConfirmPayment{ confirmation_token_id: String.t() | nil, payment_method_id: String.t() | nil, payment_processor: PolarExpress.Schemas.PaymentProcessor.t() | nil }
confirmation_token_id- ID of the Stripe confirmation token for new payment methods. Nullable.payment_method_id- ID of an existing saved payment method. Nullable.payment_processor- Payment processor used.