PolarExpress.Schemas.CustomerSessionCustomerExternalIDCreate (polar_express v0.1.5)

Copy Markdown View Source

CustomerSessionCustomerExternalIDCreate

Schema for creating a customer session using an external customer ID.

Summary

Types

t()

@type t() :: %PolarExpress.Schemas.CustomerSessionCustomerExternalIDCreate{
  external_customer_id: String.t() | nil,
  return_url: String.t() | nil
}
  • external_customer_id - External ID of the customer to create a session for.
  • return_url - When set, a back button will be shown in the customer portal to return to this URL. Nullable.

Functions

schema_name()