PolarExpress.Schemas.CustomerSessionCustomerIDCreate
(polar_express v0.1.5)
CustomerSessionCustomerIDCreate
Schema for creating a customer session using a customer ID.
Summary
Types
@type t() :: %PolarExpress.Schemas.CustomerSessionCustomerIDCreate{ customer_id: String.t() | nil, return_url: String.t() | nil }
customer_id- ID of the customer to create a session for. Format: uuid4.return_url- When set, a back button will be shown in the customer portal to return to this URL. Nullable.