CustomerStateBenefitGrant
An active benefit grant for a customer.
Summary
Types
@type t() :: %PolarExpress.Schemas.CustomerStateBenefitGrant{ benefit_id: String.t() | nil, benefit_metadata: PolarExpress.Schemas.MetadataOutputType.t() | nil, benefit_type: PolarExpress.Schemas.BenefitType.t() | nil, created_at: DateTime.t() | nil, granted_at: DateTime.t() | nil, id: String.t() | nil, modified_at: DateTime.t() | nil, properties: PolarExpress.Schemas.BenefitGrantDiscordProperties.t() | PolarExpress.Schemas.BenefitGrantGitHubRepositoryProperties.t() | PolarExpress.Schemas.BenefitGrantDownloadablesProperties.t() | PolarExpress.Schemas.BenefitGrantLicenseKeysProperties.t() | PolarExpress.Schemas.BenefitGrantCustomProperties.t() | nil }
benefit_id- The ID of the benefit concerned by this grant. Format: uuid4.benefit_metadata- The metadata of the benefit concerned by this grant.benefit_type- The type of the benefit concerned by this grant.created_at- Creation timestamp of the object. Format: date-time.granted_at- The timestamp when the benefit was granted. Format: date-time.id- The ID of the grant. Format: uuid4.modified_at- Last modification timestamp of the object. Nullable.properties