PolarExpress.Schemas.DiscountPercentageOnceForeverDurationBase
(polar_express v0.1.5)
DiscountPercentageOnceForeverDurationBase
Summary
Types
@type t() :: %PolarExpress.Schemas.DiscountPercentageOnceForeverDurationBase{ basis_points: integer() | nil, code: String.t() | nil, created_at: DateTime.t() | nil, duration: PolarExpress.Schemas.DiscountDuration.t() | nil, ends_at: DateTime.t() | nil, id: String.t() | nil, max_redemptions: integer() | nil, metadata: PolarExpress.Schemas.MetadataOutputType.t() | nil, modified_at: DateTime.t() | nil, name: String.t() | nil, organization_id: String.t() | nil, redemptions_count: integer() | nil, starts_at: DateTime.t() | nil, type: PolarExpress.Schemas.DiscountType.t() | nil }
basis_points- Discount percentage in basis points. A basis point is 1/100th of a percent. For example, 1000 basis points equals a 10% discount.code- Code customers can use to apply the discount during checkout. Nullable.created_at- Creation timestamp of the object. Format: date-time.durationends_at- Timestamp after which the discount is no longer redeemable. Nullable.id- The ID of the object. Format: uuid4.max_redemptions- Maximum number of times the discount can be redeemed. Nullable.metadatamodified_at- Last modification timestamp of the object. Nullable.name- Name of the discount. Will be displayed to the customer when the discount is applied.organization_id- The organization ID. Format: uuid4.redemptions_count- Number of times the discount has been redeemed.starts_at- Timestamp after which the discount is redeemable. Nullable.type