PolarExpress.Schemas.LegacyRecurringProductPriceFree
(polar_express v0.1.5)
LegacyRecurringProductPriceFree
A free recurring price for a product, i.e. a subscription.
Deprecated: The recurring interval should be set on the product itself.
Summary
Types
@type t() :: %PolarExpress.Schemas.LegacyRecurringProductPriceFree{ amount_type: String.t() | nil, created_at: DateTime.t() | nil, id: String.t() | nil, is_archived: boolean() | nil, legacy: boolean() | nil, modified_at: DateTime.t() | nil, price_currency: String.t() | nil, product_id: String.t() | nil, recurring_interval: PolarExpress.Schemas.SubscriptionRecurringInterval.t() | nil, source: PolarExpress.Schemas.ProductPriceSource.t() | nil, type: String.t() | nil }
amount_typecreated_at- Creation timestamp of the object. Format: date-time.id- The ID of the price. Format: uuid4.is_archived- Whether the price is archived and no longer available.legacymodified_at- Last modification timestamp of the object. Nullable.price_currency- The currency in which the customer will be charged.product_id- The ID of the product owning the price. Format: uuid4.recurring_interval- The recurring interval of the price.source- The source of the price .catalogis a predefined price, whilead_hocis a price created dynamically on a Checkout session.type- The type of the price.