OrderUpdate
Schema to update an order.
Summary
Types
@type t() :: %PolarExpress.Schemas.OrderUpdate{ billing_address: PolarExpress.Schemas.AddressInput.t() | nil, billing_name: String.t() | nil }
billing_address- The address of the customer that should appear on the invoice. Country and state fields cannot be updated. Nullable.billing_name- The name of the customer that should appear on the invoice. Nullable.