OrganizationAvatarFileCreate
Schema to create a file to be used as an organization avatar.
Summary
Types
@type t() :: %PolarExpress.Schemas.OrganizationAvatarFileCreate{ checksum_sha256_base64: String.t() | nil, mime_type: String.t() | nil, name: String.t() | nil, organization_id: String.t() | nil, service: String.t() | nil, size: integer() | nil, upload: PolarExpress.Schemas.S3FileCreateMultipart.t() | nil, version: String.t() | nil }
checksum_sha256_base64- Nullable.mime_type- MIME type of the file. Only images are supported for this type of file.nameorganization_id- Nullable.servicesize- Size of the file. A maximum of 1 MB is allowed for this type of file.uploadversion- Nullable.