ProductBenefitsUpdate
Schema to update the benefits granted by a product.
Summary
Types
@type t() :: %PolarExpress.Schemas.ProductBenefitsUpdate{benefits: [String.t()] | nil}
benefits- List of benefit IDs. Each one must be on the same organization as the product.