ProductPriceMeteredUnitCreate
Schema to create a metered price with a fixed unit price.
Summary
Types
@type t() :: %PolarExpress.Schemas.ProductPriceMeteredUnitCreate{ amount_type: String.t() | nil, cap_amount: integer() | nil, meter_id: String.t() | nil, price_currency: PolarExpress.Schemas.PresentmentCurrency.t() | nil, unit_amount: float() | String.t() | nil }
amount_typecap_amount- Optional maximum amount in cents that can be charged, regardless of the number of units consumed. Nullable.meter_id- The ID of the meter associated to the price. Format: uuid4.price_currency- The currency in which the customer will be charged.unit_amount- The price per unit in cents. Supports up to 12 decimal places.