SubscriptionMeter
Current consumption and spending for a subscription meter.
Summary
Types
@type t() :: %PolarExpress.Schemas.SubscriptionMeter{ amount: integer() | nil, consumed_units: float() | nil, created_at: DateTime.t() | nil, credited_units: integer() | nil, id: String.t() | nil, meter: PolarExpress.Schemas.Meter.t() | nil, meter_id: String.t() | nil, modified_at: DateTime.t() | nil }
amount- The amount due in cents so far in this billing period.consumed_units- The number of consumed units so far in this billing period.created_at- Creation timestamp of the object. Format: date-time.credited_units- The number of credited units so far in this billing period.id- The ID of the object. Format: uuid4.meter- The meter associated with this subscription.meter_id- The ID of the meter. Format: uuid4.modified_at- Last modification timestamp of the object. Nullable.