PolarExpress.Schemas.WebhookBenefitGrantCycledPayload
(polar_express v0.1.5)
WebhookBenefitGrantCycledPayload
Sent when a benefit grant is cycled, meaning the related subscription has been renewed for another period.
Discord & Slack support: Basic
Summary
Types
@type t() :: %PolarExpress.Schemas.WebhookBenefitGrantCycledPayload{ data: PolarExpress.Schemas.BenefitGrantWebhook.t() | nil, timestamp: DateTime.t() | nil, type: String.t() | nil }
datatimestamp- Format: date-time.type