PolarExpress.Schemas.WebhookCustomerSeatRevokedPayload
(polar_express v0.1.5)
WebhookCustomerSeatRevokedPayload
Sent when a customer seat is revoked.
This event is triggered when access to a seat is revoked, either manually by the organization or automatically when a subscription is canceled.
Summary
Types
@type t() :: %PolarExpress.Schemas.WebhookCustomerSeatRevokedPayload{ data: PolarExpress.Schemas.CustomerSeat.t() | nil, timestamp: DateTime.t() | nil, type: String.t() | nil }
datatimestamp- Format: date-time.type