WebhookCustomerUpdatedPayload
Sent when a customer is updated.
This event is fired when the customer details are updated.
If you want to be notified when a customer subscription or benefit state changes, you should listen to the customer_state_changed event.
Discord & Slack support: Basic
Summary
Types
@type t() :: %PolarExpress.Schemas.WebhookCustomerUpdatedPayload{ data: PolarExpress.Schemas.Customer.t() | nil, timestamp: DateTime.t() | nil, type: String.t() | nil }
datatimestamp- Format: date-time.type