WebhookMemberCreatedPayload
Sent when a new member is created.
A member represents an individual within a customer (team). This event is triggered when a member is added to a customer, either programmatically via the API or when an owner is automatically created for a new customer.
Discord & Slack support: Basic
Summary
Types
@type t() :: %PolarExpress.Schemas.WebhookMemberCreatedPayload{ data: PolarExpress.Schemas.Member.t() | nil, timestamp: DateTime.t() | nil, type: String.t() | nil }
datatimestamp- Format: date-time.type