WebhookMemberDeletedPayload
Sent when a member is deleted.
This event is triggered when a member is removed from a customer. Any active seats assigned to the member will be automatically revoked.
Discord & Slack support: Basic
Summary
Types
@type t() :: %PolarExpress.Schemas.WebhookMemberDeletedPayload{ data: PolarExpress.Schemas.Member.t() | nil, timestamp: DateTime.t() | nil, type: String.t() | nil }
datatimestamp- Format: date-time.type