WebhookMemberUpdatedPayload
Sent when a member is updated.
This event is triggered when member details are updated, such as their name or role within the customer.
Discord & Slack support: Basic
Summary
Types
@type t() :: %PolarExpress.Schemas.WebhookMemberUpdatedPayload{ data: PolarExpress.Schemas.Member.t() | nil, timestamp: DateTime.t() | nil, type: String.t() | nil }
datatimestamp- Format: date-time.type