WebhookOrderCreatedPayload
Sent when a new order is created.
A new order is created when:
- A customer purchases a one-time product. In this case,
billing_reasonis set topurchase. - A customer starts a subscription. In this case,
billing_reasonis set tosubscription_create. - A subscription is renewed. In this case,
billing_reasonis set tosubscription_cycle. - A subscription is upgraded or downgraded with an immediate proration invoice. In this case,
billing_reasonis set tosubscription_update.
[!WARNING] The order might not be paid yet, so the
statusfield might bepending.
Discord & Slack support: Full
Summary
Types
@type t() :: %PolarExpress.Schemas.WebhookOrderCreatedPayload{ data: PolarExpress.Schemas.Order.t() | nil, timestamp: DateTime.t() | nil, type: String.t() | nil }
datatimestamp- Format: date-time.type