PolarExpress.Schemas.WebhookSubscriptionCreatedPayload
(polar_express v0.1.5)
WebhookSubscriptionCreatedPayload
Sent when a new subscription is created.
When this event occurs, the subscription status might not be active yet, as we can still have to wait for the first payment to be processed.
Discord & Slack support: Full
Summary
Types
@type t() :: %PolarExpress.Schemas.WebhookSubscriptionCreatedPayload{ data: PolarExpress.Schemas.Subscription.t() | nil, timestamp: DateTime.t() | nil, type: String.t() | nil }
datatimestamp- Format: date-time.type