PolarExpress.Schemas.WebhookSubscriptionPastDuePayload
(polar_express v0.1.5)
WebhookSubscriptionPastDuePayload
Sent when a subscription payment fails and the subscription enters past_due status.
This is a recoverable state - the customer can update their payment method to restore the subscription. Benefits may be revoked depending on the organization's grace period settings.
If payment retries are exhausted, a subscription.revoked event will be sent.
Discord & Slack support: Full
Summary
Types
@type t() :: %PolarExpress.Schemas.WebhookSubscriptionPastDuePayload{ data: PolarExpress.Schemas.Subscription.t() | nil, timestamp: DateTime.t() | nil, type: String.t() | nil }
datatimestamp- Format: date-time.type