PolarExpress.Schemas.WebhookSubscriptionUpdatedPayload
(polar_express v0.1.6)
WebhookSubscriptionUpdatedPayload
Sent when a subscription is updated. This event fires for all changes to the subscription, including renewals.
If you want more specific events, you can listen to subscription.active, subscription.canceled, subscription.past_due, and subscription.revoked.
To listen specifically for renewals, you can listen to order.created events and check the billing_reason field.
Discord & Slack support: On cancellation, past due, and revocation. Renewals are skipped.
Summary
Types
@type t() :: %PolarExpress.Schemas.WebhookSubscriptionUpdatedPayload{ data: PolarExpress.Schemas.Subscription.t() | nil, timestamp: DateTime.t() | nil, type: String.t() | nil }
datatimestamp- Format: date-time.type