PolarExpress.Services.CustomerPortal.CustomersService
(polar_express v0.1.6)
Customers
Customers API operations.
Summary
Functions
Add Customer Payment Method
Check Email Change Token
Confirm Customer Payment Method
Delete Customer Payment Method
Get Customer
List Customer Payment Methods
Request Email Change
Update Customer
Verify Email Change
Functions
@spec add_customer_payment_method(PolarExpress.Client.t(), map(), keyword()) :: {:ok, PolarExpress.Schemas.CustomerPaymentMethodCreateResponse.t()} | {:error, PolarExpress.Error.t()}
Add Customer Payment Method
Add a payment method to the authenticated customer.
See PolarExpress.Params.CustomerPortal.CustomersAddCustomerPaymentMethodParams for parameter details.
@spec check_email_change_token(PolarExpress.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, PolarExpress.Error.t()}
Check Email Change Token
Check if an email change verification token is still valid.
See PolarExpress.Params.CustomerPortal.CustomersCheckEmailChangeTokenParams for parameter details.
@spec confirm_customer_payment_method(PolarExpress.Client.t(), map(), keyword()) :: {:ok, PolarExpress.Schemas.CustomerPaymentMethodCreateResponse.t()} | {:error, PolarExpress.Error.t()}
Confirm Customer Payment Method
Confirm a payment method for the authenticated customer.
See PolarExpress.Params.CustomerPortal.CustomersConfirmCustomerPaymentMethodParams for parameter details.
@spec delete_customer_payment_method( PolarExpress.Client.t(), String.t(), map(), keyword() ) :: {:ok, term()} | {:error, PolarExpress.Error.t()}
Delete Customer Payment Method
Delete a payment method from the authenticated customer.
See PolarExpress.Params.CustomerPortal.CustomersDeleteCustomerPaymentMethodParams for parameter details.
@spec get_customer(PolarExpress.Client.t(), map(), keyword()) :: {:ok, PolarExpress.Schemas.CustomerPortalCustomer.t()} | {:error, PolarExpress.Error.t()}
Get Customer
Get authenticated customer.
Scopes: customer_portal:read customer_portal:write
See PolarExpress.Params.CustomerPortal.CustomersGetCustomerParams for parameter details.
@spec list_customer_payment_methods(PolarExpress.Client.t(), map(), keyword()) :: {:ok, PolarExpress.ListObject.t()} | {:error, PolarExpress.Error.t()}
List Customer Payment Methods
Get saved payment methods of the authenticated customer.
See PolarExpress.Params.CustomerPortal.CustomersListCustomerPaymentMethodsParams for parameter details.
@spec request_email_change(PolarExpress.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, PolarExpress.Error.t()}
Request Email Change
Request an email change for the authenticated customer.
See PolarExpress.Params.CustomerPortal.CustomersRequestEmailChangeParams for parameter details.
@spec update_customer(PolarExpress.Client.t(), map(), keyword()) :: {:ok, PolarExpress.Schemas.CustomerPortalCustomer.t()} | {:error, PolarExpress.Error.t()}
Update Customer
Update authenticated customer.
See PolarExpress.Params.CustomerPortal.CustomersUpdateCustomerParams for parameter details.
@spec verify_email_change(PolarExpress.Client.t(), map(), keyword()) :: {:ok, PolarExpress.Schemas.CustomerEmailUpdateVerifyResponse.t()} | {:error, PolarExpress.Error.t()}
Verify Email Change
Verify an email change using the token from the verification email.
See PolarExpress.Params.CustomerPortal.CustomersVerifyEmailChangeParams for parameter details.