PolarExpress.Services.CustomerPortal.LicenseKeysService
(polar_express v0.1.5)
License-keys
LicenseKeys API operations.
Summary
Functions
Activate License Key
Deactivate License Key
Get License Key
List License Keys
Validate License Key
Functions
@spec activate_license_key(PolarExpress.Client.t(), map(), keyword()) :: {:ok, PolarExpress.Schemas.LicenseKeyActivationRead.t()} | {:error, PolarExpress.Error.t()}
Activate License Key
Activate a license key instance.
This endpoint doesn't require authentication and can be safely used on a public client, like a desktop application or a mobile app. If you plan to validate a license key on a server, use the
/v1/license-keys/activateendpoint instead.
See PolarExpress.Params.CustomerPortal.LicenseKeysActivateLicenseKeyParams for parameter details.
@spec deactivate_license_key(PolarExpress.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, PolarExpress.Error.t()}
Deactivate License Key
Deactivate a license key instance.
This endpoint doesn't require authentication and can be safely used on a public client, like a desktop application or a mobile app. If you plan to validate a license key on a server, use the
/v1/license-keys/deactivateendpoint instead.
See PolarExpress.Params.CustomerPortal.LicenseKeysDeactivateLicenseKeyParams for parameter details.
@spec get_license_key(PolarExpress.Client.t(), String.t(), map(), keyword()) :: {:ok, PolarExpress.Schemas.LicenseKeyWithActivations.t()} | {:error, PolarExpress.Error.t()}
Get License Key
Get a license key.
Scopes: customer_portal:read customer_portal:write
See PolarExpress.Params.CustomerPortal.LicenseKeysGetLicenseKeyParams for parameter details.
@spec list_license_keys(PolarExpress.Client.t(), map(), keyword()) :: {:ok, PolarExpress.ListObject.t()} | {:error, PolarExpress.Error.t()}
List License Keys
Scopes: customer_portal:read customer_portal:write
See PolarExpress.Params.CustomerPortal.LicenseKeysListLicenseKeysParams for parameter details.
@spec validate_license_key(PolarExpress.Client.t(), map(), keyword()) :: {:ok, PolarExpress.Schemas.ValidatedLicenseKey.t()} | {:error, PolarExpress.Error.t()}
Validate License Key
Validate a license key.
This endpoint doesn't require authentication and can be safely used on a public client, like a desktop application or a mobile app. If you plan to validate a license key on a server, use the
/v1/license-keys/validateendpoint instead.
See PolarExpress.Params.CustomerPortal.LicenseKeysValidateLicenseKeyParams for parameter details.