StripeElixir.Params.AccountPersonCreateParams.Documents
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.AccountPersonCreateParams.Documents{ company_authorization: map() | nil, passport: map() | nil, visa: map() | nil }
company_authorization- One or more documents that demonstrate proof that this person is authorized to represent the company.passport- One or more documents showing the person's passport page with photo and personal data.visa- One or more documents showing the person's visa required for living in the country where they are residing.