StripeElixir.Params.Billing.AlertCreateParams.UsageThreshold
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.Billing.AlertCreateParams.UsageThreshold{ filters: [map()] | nil, gte: integer() | nil, meter: String.t() | nil, recurrence: String.t() | nil }
filters- The filters allows limiting the scope of this usage alert. You can only specify up to one filter at this time.gte- Defines at which value the alert will fire.meter- The Billing Meter ID whose usage is monitored. Max length: 5000.recurrence- Defines how the alert will behave. Possible values:one_time.