Parameters for coupon create.
Summary
Types
@type t() :: %StripeElixir.Params.CouponCreateParams{ amount_off: integer() | nil, applies_to: map() | nil, currency: String.t() | nil, currency_options: map() | nil, duration: String.t() | nil, duration_in_months: integer() | nil, expand: [String.t()] | nil, id: String.t() | nil, max_redemptions: integer() | nil, metadata: map() | nil, name: String.t() | nil, percent_off: float() | nil, redeem_by: integer() | nil }
amount_off- A positive integer representing the amount to subtract from an invoice total (required ifpercent_offis not passed).applies_to- A hash containing directions for what this Coupon will apply discounts to.currency- Three-letter ISO code for the currency of theamount_offparameter (required ifamount_offis passed). Format: ISO 4217 currency code.currency_options- Coupons defined in each available currency option (only supported ifamount_offis passed). Each key must be a three-letter ISO currency code and a supported currency.duration- Specifies how long the discount will be in effect if used on a subscription. Defaults toonce. Possible values:forever,once,repeating.duration_in_months- Required only ifdurationisrepeating, in which case it must be a positive integer that specifies the number of months the discount will be in effect.expand- Specifies which fields in the response should be expanded.id- Unique string of your choice that will be used to identify this coupon when applying it to a customer. If you don't want to specify a particular code, you can leave the ID blank and we'll generate a random code for you. Max length: 5000.max_redemptions- A positive integer specifying the number of times the coupon can be redeemed before it's no longer valid. For example, you might have a 50% off coupon that the first 20 readers of your blog can use.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.name- Name of the coupon displayed to customers on, for instance invoices, or receipts. By default theidis shown ifnameis not set. Max length: 40.percent_off- A positive float larger than 0, and smaller or equal to 100, that represents the discount the coupon will apply (required ifamount_offis not passed).redeem_by- Unix timestamp specifying the last time at which the coupon can be redeemed (cannot be set to more than 5 years in the future). After the redeem_by date, the coupon can no longer be applied to new customers. Format: Unix timestamp.