Parameters for customer list.
Summary
Types
@type t() :: %StripeElixir.Params.CustomerListParams{ created: map() | nil, email: String.t() | nil, ending_before: String.t() | nil, expand: [String.t()] | nil, limit: integer() | nil, starting_after: String.t() | nil, test_clock: String.t() | nil }
created- Only return customers that were created during the given date interval.email- A case-sensitive filter on the list based on the customer'semailfield. The value must be a string. Max length: 512.ending_before- A cursor for use in pagination.ending_beforeis an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting withobj_bar, your subsequent call can includeending_before=obj_barin order to fetch the previous page of the list. Max length: 5000.expand- Specifies which fields in the response should be expanded.limit- A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.starting_after- A cursor for use in pagination.starting_afteris an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending withobj_foo, your subsequent call can includestarting_after=obj_fooin order to fetch the next page of the list. Max length: 5000.test_clock- Provides a list of customers that are associated with the specified test clock. The response will not include customers with test clocks if this parameter is not set. Max length: 5000.