StripeElixir.Params.CustomerPaymentSourceUpdateParams
(stripe_elixir v0.1.0)
Parameters for customer payment source update.
Summary
Types
@type t() :: %StripeElixir.Params.CustomerPaymentSourceUpdateParams{ account_holder_name: String.t() | nil, account_holder_type: String.t() | nil, address_city: String.t() | nil, address_country: String.t() | nil, address_line1: String.t() | nil, address_line2: String.t() | nil, address_state: String.t() | nil, address_zip: String.t() | nil, exp_month: String.t() | nil, exp_year: String.t() | nil, expand: [String.t()] | nil, metadata: map() | nil, name: String.t() | nil, owner: map() | nil }
account_holder_name- The name of the person or business that owns the bank account. Max length: 5000.account_holder_type- The type of entity that holds the account. This can be eitherindividualorcompany. Possible values:company,individual. Max length: 5000.address_city- City/District/Suburb/Town/Village. Max length: 5000.address_country- Billing address country, if provided when creating card. Max length: 5000.address_line1- Address line 1 (Street address/PO Box/Company name). Max length: 5000.address_line2- Address line 2 (Apartment/Suite/Unit/Building). Max length: 5000.address_state- State/County/Province/Region. Max length: 5000.address_zip- ZIP or postal code. Max length: 5000.exp_month- Two digit number representing the card’s expiration month. Max length: 5000.exp_year- Four digit number representing the card’s expiration year. Max length: 5000.expand- Specifies which fields in the response should be expanded.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.name- Cardholder name. Max length: 5000.owner