StripeElixir.Params.InvoiceCreateParams.TransferData
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.InvoiceCreateParams.TransferData{ amount: integer() | nil, destination: String.t() | nil }
amount- The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred.destination- ID of an existing, connected Stripe account.