Parameters for card update.
Summary
Types
@type t() :: %StripeElixir.Params.Issuing.CardUpdateParams{ cancellation_reason: String.t() | nil, expand: [String.t()] | nil, metadata: map() | nil, personalization_design: String.t() | nil, pin: map() | nil, shipping: map() | nil, spending_controls: map() | nil, status: String.t() | nil }
cancellation_reason- Reason why thestatusof this card iscanceled. Possible values:lost,stolen.expand- Specifies which fields in the response should be expanded.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.personalization_design- Max length: 5000.pin- The desired new PIN for this card.shipping- Updated shipping information for the card.spending_controls- Rules that control spending for this card. Refer to our documentation for more details.status- Dictates whether authorizations can be approved on this card. May be blocked from activating cards depending on past-due Cardholder requirements. Defaults toinactive. If this card is being canceled because it was lost or stolen, this information should be provided ascancellation_reason. Possible values:active,canceled,inactive.