StripeElixir.Params.Issuing.CardholderCreateParams.Individual
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.Issuing.CardholderCreateParams.Individual{ card_issuing: map() | nil, dob: map() | nil, first_name: String.t() | nil, last_name: String.t() | nil, verification: map() | nil }
card_issuing- Information related to the card_issuing program for this cardholder.dob- The date of birth of this cardholder. Cardholders must be older than 13 years old.first_name- The first name of this cardholder. Required before activating Cards. This field cannot contain any numbers, special characters (except periods, commas, hyphens, spaces and apostrophes) or non-latin letters.last_name- The last name of this cardholder. Required before activating Cards. This field cannot contain any numbers, special characters (except periods, commas, hyphens, spaces and apostrophes) or non-latin letters.verification- Government-issued ID document for this cardholder.