StripeElixir.Params.PaymentIntentCreateParams.RadarOptions
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.PaymentIntentCreateParams.RadarOptions{ session: String.t() | nil }
session- A Radar Session is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments. Max length: 5000.