Parameters for payment intent retrieve.
Summary
Types
@type t() :: %StripeElixir.Params.PaymentIntentRetrieveParams{ client_secret: String.t() | nil, expand: [String.t()] | nil }
client_secret- The client secret of the PaymentIntent. We require it if you use a publishable key to retrieve the source. Max length: 5000.expand- Specifies which fields in the response should be expanded.