StripeElixir.Params.PaymentRecordReportPaymentAttemptInformationalParams
(stripe_elixir v0.1.0)
Parameters for payment record report payment attempt informational.
Summary
Types
@type t() :: %StripeElixir.Params.PaymentRecordReportPaymentAttemptInformationalParams{ customer_details: map() | nil, description: map() | nil, expand: [String.t()] | nil, metadata: map() | nil, shipping_details: map() | nil }
customer_details- Customer information for this payment.description- An arbitrary string attached to the object. Often useful for displaying to users.expand- Specifies which fields in the response should be expanded.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.shipping_details- Shipping information for this payment.