StripeElixir.Params.Radar.PaymentEvaluationCreateParams.CustomerDetails
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.Radar.PaymentEvaluationCreateParams.CustomerDetails{ customer: String.t() | nil, customer_account: String.t() | nil, email: String.t() | nil, name: String.t() | nil, phone: String.t() | nil }
customer- The ID of the customer associated with the payment evaluation. Max length: 5000.customer_account- The ID of the Account representing the customer associated with the payment evaluation. Max length: 5000.email- The customer's email address.name- The customer's full name or business name. Max length: 5000.phone- The customer's phone number.