StripeElixir.Params.Reporting.ReportRunCreateParams
(stripe_elixir v0.1.0)
Parameters for report run create.
Summary
Types
@type t() :: %StripeElixir.Params.Reporting.ReportRunCreateParams{ expand: [String.t()] | nil, parameters: map() | nil, report_type: String.t() }
expand- Specifies which fields in the response should be expanded.parameters- Parameters specifying how the report should be run. Different Report Types have different required and optional parameters, listed in the API Access to Reports documentation.report_type- The ID of the report type to run, such as"balance.summary.1".