StripeElixir.Params.Tax.CalculationCreateParams.CustomerDetails
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.Tax.CalculationCreateParams.CustomerDetails{ address: map() | nil, address_source: String.t() | nil, ip_address: String.t() | nil, tax_ids: [map()] | nil, taxability_override: String.t() | nil }
address- The customer's postal address (for example, home or business location).address_source- The type of customer address provided. Possible values:billing,shipping.ip_address- The customer's IP address (IPv4 or IPv6).tax_ids- The customer's tax IDs. Stripe Tax might consider a transaction with applicable tax IDs to be B2B, which might affect the tax calculation result. Stripe Tax doesn't validate tax IDs for correctness.taxability_override- Overrides the tax calculation result to allow you to not collect tax from your customer. Use this if you've manually checked your customer's tax exemptions. Prefer providing the customer'stax_idswhere possible, which automatically determines whetherreverse_chargeapplies. Possible values:customer_exempt,none,reverse_charge.