Parameters for registration update.
Summary
Types
@type t() :: %StripeElixir.Params.Tax.RegistrationUpdateParams{ active_from: map() | nil, expand: [String.t()] | nil, expires_at: map() | nil }
active_from- Time at which the registration becomes active. It can be eithernowto indicate the current time, or a timestamp measured in seconds since the Unix epoch.expand- Specifies which fields in the response should be expanded.expires_at- If set, the registration stops being active at this time. If not set, the registration will be active indefinitely. It can be eithernowto indicate the current time, or a timestamp measured in seconds since the Unix epoch.