StripeElixir.Params.Tax.TransactionCreateReversalParams.LineItems
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.Tax.TransactionCreateReversalParams.LineItems{ amount: integer() | nil, amount_tax: integer() | nil, metadata: map() | nil, original_line_item: String.t() | nil, quantity: integer() | nil, reference: String.t() | nil }
amount- The amount to reverse, in the smallest currency unit in negative.amount_tax- The amount of tax to reverse, in the smallest currency unit in negative.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.original_line_item- Theidof the line item to reverse in the original transaction. Max length: 5000.quantity- The quantity reversed. Appears in tax exports, but does not affect the amount of tax reversed.reference- A custom identifier for this line item in the reversal transaction, such as 'L1-refund'. Max length: 500.