StripeElixir.Params.Terminal.OnboardingLinkCreateParams
(stripe_elixir v0.1.0)
Parameters for onboarding link create.
Summary
Types
@type t() :: %StripeElixir.Params.Terminal.OnboardingLinkCreateParams{ expand: [String.t()] | nil, link_options: map(), link_type: String.t(), on_behalf_of: String.t() | nil }
expand- Specifies which fields in the response should be expanded.link_options- Specific fields needed to generate the desired link type.link_type- The type of link being generated. Possible values:apple_terms_and_conditions.on_behalf_of- Stripe account ID to generate the link for. Max length: 5000.