StripeElixir.Params.TestHelpers.Issuing.TransactionCreateForceCaptureParams.PurchaseDetails
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.TestHelpers.Issuing.TransactionCreateForceCaptureParams.PurchaseDetails{ fleet: map() | nil, flight: map() | nil, fuel: map() | nil, lodging: map() | nil, receipt: [map()] | nil, reference: String.t() | nil }
fleet- Fleet-specific information for transactions using Fleet cards.flight- Information about the flight that was purchased with this transaction.fuel- Information about fuel that was purchased with this transaction.lodging- Information about lodging that was purchased with this transaction.receipt- The line items in the purchase.reference- A merchant-specific order number. Max length: 5000.