StripeElixir.Params.TestHelpers.Issuing.TransactionRefundParams
(stripe_elixir v0.1.0)
Parameters for transaction refund.
Summary
Types
@type t() :: %StripeElixir.Params.TestHelpers.Issuing.TransactionRefundParams{ expand: [String.t()] | nil, refund_amount: integer() | nil }
expand- Specifies which fields in the response should be expanded.refund_amount- The total amount to attempt to refund. This amount is in the provided currency, or defaults to the cards currency, and in the smallest currency unit.