StripeElixir.Params.Treasury.DebitReversalCreateParams
(stripe_elixir v0.1.0)
Parameters for debit reversal create.
Summary
Types
@type t() :: %StripeElixir.Params.Treasury.DebitReversalCreateParams{ expand: [String.t()] | nil, metadata: map() | nil, received_debit: String.t() }
expand- Specifies which fields in the response should be expanded.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.received_debit- The ReceivedDebit to reverse. Max length: 5000.