StripeElixir.Params.Treasury.InboundTransferCreateParams
(stripe_elixir v0.1.0)
Parameters for inbound transfer create.
Summary
Types
@type t() :: %StripeElixir.Params.Treasury.InboundTransferCreateParams{ amount: integer(), currency: String.t(), description: String.t() | nil, expand: [String.t()] | nil, financial_account: String.t(), metadata: map() | nil, origin_payment_method: String.t(), statement_descriptor: String.t() | nil }
amount- Amount (in cents) to be transferred.currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.description- An arbitrary string attached to the object. Often useful for displaying to users. Max length: 5000.expand- Specifies which fields in the response should be expanded.financial_account- The FinancialAccount to send funds to.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.origin_payment_method- The origin payment method to be debited for the InboundTransfer. Max length: 5000.statement_descriptor- The complete description that appears on your customers' statements. Maximum 10 characters. Can only include -#.$&*, spaces, and alphanumeric characters. Max length: 10.