StripeElixir.Params.Treasury.OutboundTransferCreateParams
(stripe_elixir v0.1.0)
Parameters for outbound transfer create.
Summary
Types
@type t() :: %StripeElixir.Params.Treasury.OutboundTransferCreateParams{ amount: integer(), currency: String.t(), description: String.t() | nil, destination_payment_method: String.t() | nil, destination_payment_method_data: map() | nil, destination_payment_method_options: map() | nil, expand: [String.t()] | nil, financial_account: String.t(), metadata: map() | nil, statement_descriptor: String.t() | nil }
amount- Amount (in cents) to be transferred.currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.description- An arbitrary string attached to the object. Often useful for displaying to users. Max length: 5000.destination_payment_method- The PaymentMethod to use as the payment instrument for the OutboundTransfer. Max length: 5000.destination_payment_method_data- Hash used to generate the PaymentMethod to be used for this OutboundTransfer. Exclusive withdestination_payment_method.destination_payment_method_options- Hash describing payment method configuration details.expand- Specifies which fields in the response should be expanded.financial_account- The FinancialAccount to pull funds from.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.statement_descriptor- Statement descriptor to be shown on the receiving end of an OutboundTransfer. Maximum 10 characters forachtransfers or 140 characters forus_domestic_wiretransfers. The default value is "transfer". Can only include -#.$&*, spaces, and alphanumeric characters. Max length: 5000.