Parameters for account list.
Summary
Types
@type t() :: %StripeElixir.Params.V2.Core.AccountListParams{ applied_configurations: [String.t()] | nil, closed: boolean() | nil, limit: integer() | nil }
applied_configurations- Filter only accounts that have all of the configurations specified. If omitted, returns all accounts regardless of which configurations they have.closed- Filter by whether the account is closed. If omitted, returns only Accounts that are not closed.limit- The upper limit on the number of accounts returned by the List Account request.