CustomerBalanceResourceCashBalanceTransactionResourceAdjustedForOverdraft
Summary
Types
@type t() :: %StripeElixir.Resources.AdjustedForOverdraft{ balance_transaction: String.t() | map(), linked_transaction: String.t() | map() }
balance_transaction- The Balance Transaction that corresponds to funds taken out of your Stripe balance. Expandable.linked_transaction- The Cash Balance Transaction that brought the customer balance negative, triggering the clawback of funds. Expandable.