Balance
This is an object representing your Stripe balance. You can retrieve it to see the balance currently on your Stripe account.
The top-level available and pending comprise your "payments balance."
Related guide: Balances and settlement time, Understanding Connect account balances
Summary
Types
@type t() :: %StripeElixir.Resources.Balance{ available: [map()], connect_reserved: [map()] | nil, instant_available: [map()] | nil, issuing: map() | nil, livemode: boolean(), object: String.t(), pending: [map()], refund_and_dispute_prefunding: map() | nil }
available- Available funds that you can transfer or pay out automatically by Stripe or explicitly through the Transfers API or Payouts API. You can find the available balance for each currency and payment type in thesource_typesproperty. Expandable.connect_reserved- Funds held due to negative balances on connected accounts where account.controller.requirement_collection isapplication, which includes Custom accounts. You can find the connect reserve balance for each currency and payment type in thesource_typesproperty. Expandable.instant_available- Funds that you can pay out using Instant Payouts. Expandable.issuing- Expandable.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.object- String representing the object's type. Objects of the same type share the same value. Possible values:balance.pending- Funds that aren't available in the balance yet. You can find the pending balance for each currency and each payment type in thesource_typesproperty. Expandable.refund_and_dispute_prefunding- Expandable.