FundingInstructionsBankTransfer
Summary
Types
@type t() :: %StripeElixir.Resources.BankTransfer{ country: String.t(), financial_addresses: [map()], type: String.t() }
country- The country of the bank account to fund Max length: 5000.financial_addresses- A list of financial addresses that can be used to fund a particular balance Expandable.type- The bank_transfer type Possible values:eu_bank_transfer,jp_bank_transfer.