ClimateRemovalsOrders
Orders represent your intent to purchase a particular Climate product. When you create an order, the payment is deducted from your merchant balance.
Summary
Types
@type t() :: %StripeElixir.Resources.Climate.Order{ amount_fees: integer(), amount_subtotal: integer(), amount_total: integer(), beneficiary: map() | nil, canceled_at: integer(), cancellation_reason: String.t(), certificate: String.t(), confirmed_at: integer(), created: integer(), currency: String.t(), delayed_at: integer(), delivered_at: integer(), delivery_details: [map()], expected_delivery_year: integer(), id: String.t(), livemode: boolean(), metadata: map(), metric_tons: String.t(), object: String.t(), product: String.t() | map(), product_substituted_at: integer(), status: String.t() }
amount_fees- Total amount of Frontier's service fees in the currency's smallest unit.amount_subtotal- Total amount of the carbon removal in the currency's smallest unit.amount_total- Total amount of the order including fees in the currency's smallest unit.beneficiary- Expandable.canceled_at- Time at which the order was canceled. Measured in seconds since the Unix epoch. Format: Unix timestamp. Nullable.cancellation_reason- Reason for the cancellation of this order. Possible values:expired,product_unavailable,requested. Nullable.certificate- For delivered orders, a URL to a delivery certificate for the order. Max length: 5000. Nullable.confirmed_at- Time at which the order was confirmed. Measured in seconds since the Unix epoch. Format: Unix timestamp. Nullable.created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.currency- Three-letter ISO currency code, in lowercase, representing the currency for this order. Max length: 5000.delayed_at- Time at which the order's expected_delivery_year was delayed. Measured in seconds since the Unix epoch. Format: Unix timestamp. Nullable.delivered_at- Time at which the order was delivered. Measured in seconds since the Unix epoch. Format: Unix timestamp. Nullable.delivery_details- Details about the delivery of carbon removal for this order. Expandable.expected_delivery_year- The year this order is expected to be delivered.id- Unique identifier for the object. Max length: 5000.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.metric_tons- Quantity of carbon removal that is included in this order. Format: decimal string.object- String representing the object's type. Objects of the same type share the same value. Possible values:climate.order.product- Unique ID for the ClimateProductthis order is purchasing. Expandable.product_substituted_at- Time at which the order's product was substituted for a different product. Measured in seconds since the Unix epoch. Format: Unix timestamp. Nullable.status- The current status of this order. Possible values:awaiting_funds,canceled,confirmed,delivered,open.