StripeElixir.Resources.FinancialConnections.AccountOwnership
(stripe_elixir v0.1.0)
BankConnectionsResourceOwnership
Describes a snapshot of the owners of an account at a particular point in time.
Summary
Types
@type t() :: %StripeElixir.Resources.FinancialConnections.AccountOwnership{ created: integer(), id: String.t(), object: String.t(), owners: map() }
created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.id- Unique identifier for the object. Max length: 5000.object- String representing the object's type. Objects of the same type share the same value. Possible values:financial_connections.account_ownership.owners- A paginated list of owners for this account. Expandable.