setup_intent_payment_method_options_card_mandate_options
Summary
Types
@type t() :: %StripeElixir.Resources.MandateOptions{ amount: integer(), amount_type: String.t(), currency: String.t(), description: String.t(), end_date: integer(), interval: String.t(), interval_count: integer(), reference: String.t(), start_date: integer(), supported_types: [String.t()] }
amount- Amount to be charged for future payments.amount_type- One offixedormaximum. Iffixed, theamountparam refers to the exact amount to be charged in future payments. Ifmaximum, the amount charged can be up to the value passed for theamountparam. Possible values:fixed,maximum.currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.description- A description of the mandate or subscription that is meant to be displayed to the customer. Max length: 200. Nullable.end_date- End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date. Format: Unix timestamp. Nullable.interval- Specifies payment frequency. One ofday,week,month,year, orsporadic. Possible values:day,month,sporadic,week,year.interval_count- The number of intervals between payments. For example,interval=monthandinterval_count=3indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional wheninterval=sporadic. Nullable.reference- Unique identifier for the mandate or subscription. Max length: 80.start_date- Start date of the mandate or subscription. Start date should not be lesser than yesterday. Format: Unix timestamp.supported_types- Specifies the type of mandates supported. Possible values areindia. Nullable.