ScheduledQueryRun
If you have scheduled a Sigma query, you'll
receive a sigma.scheduled_query_run.created webhook each time the query
runs. The webhook contains a ScheduledQueryRun object, which you can use to
retrieve the query results.
Summary
Types
@type t() :: %StripeElixir.Resources.Sigma.ScheduledQueryRun{ created: integer(), data_load_time: integer(), error: map() | nil, file: String.t() | map(), id: String.t(), livemode: boolean(), object: String.t(), result_available_until: integer(), sql: String.t(), status: String.t(), title: String.t() }
created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.data_load_time- When the query was run, Sigma contained a snapshot of your Stripe data at this time. Format: Unix timestamp.error- Expandable.file- The file object representing the results of the query. Nullable. Expandable.id- Unique identifier for the object. Max length: 5000.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.object- String representing the object's type. Objects of the same type share the same value. Possible values:scheduled_query_run.result_available_until- Time at which the result expires and is no longer available for download. Format: Unix timestamp.sql- SQL for the query. Max length: 100000.status- The query's execution status, which will becompletedfor successful runs, andcanceled,failed, ortimed_outotherwise. Max length: 5000.title- Title of the query. Max length: 5000.