NotificationWebhookEndpoint
You can configure webhook endpoints via the API to be notified about events that happen in your Stripe account or connected accounts.
Most users configure webhooks from the dashboard, which provides a user interface for registering and testing your webhook endpoints.
Related guide: Setting up webhooks
Summary
Types
@type t() :: %StripeElixir.Resources.WebhookEndpoint{ api_version: String.t(), application: String.t(), created: integer(), description: String.t(), enabled_events: [String.t()], id: String.t(), livemode: boolean(), metadata: map(), object: String.t(), secret: String.t() | nil, status: String.t(), url: String.t() }
api_version- The API version events are rendered as for this webhook endpoint. Max length: 5000. Nullable.application- The ID of the associated Connect application. Max length: 5000. Nullable.created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.description- An optional description of what the webhook is used for. Max length: 5000. Nullable.enabled_events- The list of events to enable for this endpoint.['*']indicates that all events are enabled, except those that require explicit selection.id- Unique identifier for the object. Max length: 5000.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.object- String representing the object's type. Objects of the same type share the same value. Possible values:webhook_endpoint.secret- The endpoint's secret, used to generate webhook signatures. Only returned at creation. Max length: 5000.status- The status of the webhook. It can beenabledordisabled. Max length: 5000.url- The URL of the webhook endpoint. Max length: 5000.