StripeElixir.Services.CustomerCashBalanceTransactionService
(stripe_elixir v0.1.0)
CustomerCashBalanceTransaction
Customers with certain payments enabled have a cash balance, representing funds that were paid by the customer to a merchant, but have not yet been allocated to a payment. Cash Balance Transactions represent when funds are moved into or out of this balance. This includes funding by the customer, allocation to payments, and refunds to the customer.
Summary
Functions
@spec list(StripeElixir.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
List cash balance transactions
Returns a list of transactions that modified the customer’s cash balance.
@spec retrieve(StripeElixir.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Retrieve a cash balance transaction
Retrieves a specific cash balance transaction, which updated the customer’s cash balance.