StripeElixir.Services.Identity.VerificationReportService
(stripe_elixir v0.1.0)
GelatoVerificationReport
A VerificationReport is the result of an attempt to collect and verify data from a user.
The collection of verification checks performed is determined from the type and options
parameters used. You can find the result of each verification check performed in the
appropriate sub-resource: document, id_number, selfie.
Each VerificationReport contains a copy of any data collected by the user as well as reference IDs which can be used to access collected images through the FileUpload API. To configure and create VerificationReports, use the VerificationSession API.
Related guide: Accessing verification results.
Summary
Functions
@spec list(StripeElixir.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
List VerificationReports
List all verification reports.
@spec retrieve(StripeElixir.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Retrieve a VerificationReport
Retrieves an existing VerificationReport