IssuingAuthorization
When an issued card is used to make a purchase, an Issuing Authorization
object is created. Authorizations must be approved for the
purchase to be completed successfully.
Related guide: Issued card authorizations
Summary
Functions
Approve an authorization
Decline an authorization
List all authorizations
Retrieve an authorization
Update an authorization
Functions
@spec approve(StripeElixir.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Approve an authorization
[Deprecated] Approves a pending Issuing Authorization object. This request should be made within the timeout window of the real-time authorization flow.
This method is deprecated. Instead, respond directly to the webhook request to approve an authorization.
@spec decline(StripeElixir.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Decline an authorization
[Deprecated] Declines a pending Issuing Authorization object. This request should be made within the timeout window of the real time authorization flow.
This method is deprecated. Instead, respond directly to the webhook request to decline an authorization.
@spec list(StripeElixir.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
List all authorizations
Returns a list of Issuing Authorization objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
@spec retrieve(StripeElixir.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Retrieve an authorization
Retrieves an Issuing Authorization object.
@spec update(StripeElixir.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Update an authorization
Updates the specified Issuing Authorization object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.