StripeElixir.Services.Issuing.PhysicalBundleService
(stripe_elixir v0.1.0)
IssuingPhysicalBundle
A Physical Bundle represents the bundle of physical items - card stock, carrier letter, and envelope - that is shipped to a cardholder when you create a physical card.
Summary
Functions
@spec list(StripeElixir.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
List all physical bundles
Returns a list of physical bundle objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
@spec retrieve(StripeElixir.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Retrieve a physical bundle
Retrieves a physical bundle object.