OAuth API operations for Stripe Connect.
Summary
Functions
Build an OAuth authorize URL for Stripe Connect.
Deauthorize a connected account.
Exchange an authorization code for an access token, or refresh a token.
OAuth API operations for Stripe Connect.
Build an OAuth authorize URL for Stripe Connect.
Deauthorize a connected account.
Exchange an authorization code for an access token, or refresh a token.