TaxProductResourceTaxAssociation
A Tax Association exposes the Tax Transactions that Stripe attempted to create on your behalf based on the PaymentIntent input
Summary
Functions
Find a Tax Association
Functions
@spec find(StripeElixir.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Find a Tax Association
Finds a tax association object by PaymentIntent id.