TaxProductResourceTaxCode
Tax codes classify goods and services for tax purposes.
Summary
Functions
@spec list(StripeElixir.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
List all tax codes
A list of all tax codes available to add to Products in order to allow specific tax calculations.
@spec retrieve(StripeElixir.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Retrieve a tax code
Retrieves the details of an existing tax code. Supply the unique tax code ID and Stripe will return the corresponding tax code information.