StripeElixir.Services.TestHelpers.Issuing.PersonalizationDesignService
(stripe_elixir v0.1.0)
PersonalizationDesign API operations.
Summary
Functions
Activate a testmode personalization design
Deactivate a testmode personalization design
Reject a testmode personalization design
Functions
@spec activate(StripeElixir.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Activate a testmode personalization design
Updates the status of the specified testmode personalization design object to active.
@spec deactivate(StripeElixir.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Deactivate a testmode personalization design
Updates the status of the specified testmode personalization design object to inactive.
@spec reject(StripeElixir.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Reject a testmode personalization design
Updates the status of the specified testmode personalization design object to rejected.